#include "bsp.h"
#include "rgb.h"
#include "tty.h"

#if 1
#define DELTA	0x0001U
#define STEPS	0x00ffU
#define HOLD_MS 150
#else
#define DELTA   0x0008U
#define STEPS   0x001fU
#define HOLD_MS 5
#endif

static unsigned long long next = 1;

int
rand(void)
{
  /* This multiplier was obtained from Knuth, D.E., "The Art of
     Computer Programming," Vol 2, Seminumerical Algorithms, Third
     Edition, Addison-Wesley, 1998, p. 106 (line 26) & p. 108 */
  next = next * 6364136223846793005LL + 1;
  return (int)(next >> 32);
}

extern int sec;

static void
rgbpoll (int rm, int gm, int bm)
{
  unsigned int i, j;
  for (i=0; i<0xff; i+=2)
    {
      set_rgb (i & rm, i & gm, i & bm);
      wait_ms (1);
    }
  set_rgb (rm, gm, bm);
  wait_ms (60);
  for (; i>0; i -= 2)
    {
      set_rgb (i & rm, i & gm, i & bm);
      wait_ms (1);
    }
}

static const char * const color_names[] = {
  "black", "red", "green", "yellow",
  "blue", "magenta", "cyan", "white"
};

main()
{
  int i, i2=-1, i3=-1, j, again;
  unsigned int r = 0, g = 0, b = 0;
  unsigned int tr = 0, tg = 0, tb = 0;
  int col;

  pd2 = 0xff;
#ifdef MORE_LEDS
  pd1 = 0x0f;
#endif

  tty_init ();

  tty_putc ('\n');
  tty_puts ("Welcome to this gR8C board!\n");
  tty_puts ("R8C/33C Devcon 2010 Lab Edition\n");
  tty_putc ('\n');

  tty_puts ("Testing LEDs... ");
#define SMS 300
  set_rgb(0, 0, 0);

#ifdef MORE_LEDS
  tty_puts(" P1.0");
  p1 = 1; wait_ms (SMS);
  tty_puts(" P1.1");
  p1 = 2; wait_ms (SMS);
  tty_puts(" P1.2");
  p1 = 4; wait_ms (SMS);
  tty_puts(" P1.3");
  p1 = 8; wait_ms (SMS);
  p1 = 0;
#endif

  tty_puts(" Red");
  rgbpoll (~0, 0, 0);
  tty_puts(" Green");
  rgbpoll (0, ~0, 0);
  tty_puts(" Blue");
  rgbpoll (0, 0, ~0);
  tty_putc ('\n');

#ifdef MORE_LEDS
  start_timer_b ();
#endif

  tty_puts ("\nRunning...");
  col = 5;
  i = 0;
  while (1)
    {
#ifdef MORE_LEDS
      p1 = i;
#endif
      again = 0;

#define BUMP(c,tc) \
      if (c < tc) \
	{ \
	  again = 1; \
	  c += DELTA; \
	} \
      else if (c > tc) \
	{ \
	  again = 1; \
	  c -= DELTA; \
	} 

      BUMP (r, tr);
      BUMP (g, tg);
      BUMP (b, tb);

      set_rgb (r, g, b);
      wait_ms (5);

      if (again)
	continue;

      do {
	i = rand () & 7;
      } while (i == i2 || i == i3);
      i3 = i2;
      i2 = i;

      tr = (i & 1) ? DELTA * STEPS : 0;
      tg = (i & 2) ? DELTA * STEPS : 0;
      tb = (i & 4) ? DELTA * STEPS : 0;

      tty_putc (' ');
      tty_putc ("KRGYBMCW"[i]);
      if (++col == 30)
        {
          tty_putc('\n');
          col = 0;
        }
      wait_ms (HOLD_MS);
    }
}
