;/*******************************************************************************
;*
;* Device       : R8C/33C Group
;*
;* File Name    : SFR_R833c.inc
;*
;* Abstract     : definition of R8C/33C Group SFR
;*
;* History      : 1.10  ( 2010-02-26 ) [Hardware Manual Revision : 1.00]
;*                       correct comment : dtcct0`23
;*                1.00  ( 2009-11-20 ) [Hardware Manual Revision : 0.10]
;*
;*  Copyright(c) 2010 Renesas Technology Corp.,All Rights Reserved.
;*
;*******************************************************************************/
;
;-------------------------------------------------------
;   Processor mode register 0
;-------------------------------------------------------
pm0					.equ		0004h
;
pm03				.btequ		3,pm0		; Software reset bit
;
;-------------------------------------------------------
;   Processor mode register 1
;-------------------------------------------------------
pm1					.equ		0005h
;
pm12				.btequ		2,pm1		; WDT interrupt/reset switch bit
;
;-------------------------------------------------------
;   System clock control register 0
;-------------------------------------------------------
cm0					.equ		0006h
;
cm01				.btequ		1,cm0		; Xin-Xcin switch bit
cm02				.btequ		2,cm0		; Wait mode peripheral function clock stop bit
cm03				.btequ		3,cm0		; Xcin clock stop bit
cm04				.btequ		4,cm0		; Port/XCIN-XCOUT switch bit
cm05				.btequ		5,cm0		; Xin clock (Xin-Xout) stop bit
cm06				.btequ		6,cm0		; CPU clock division select bit 0
cm07				.btequ		7,cm0		; XIN, XCIN clock select bit
;
;-------------------------------------------------------
;   System clock control register 1
;-------------------------------------------------------
cm1					.equ		0007h
;
cm10				.btequ		0,cm1		; All clock stop control bit
cm11				.btequ		1,cm1		; XIN-XOUT on-chip feedback resistor select bit
cm12				.btequ		2,cm1		; XCIN-XCOUT on-chip feedback resistor select bit
cm13				.btequ		3,cm1		; Port/XIN-XOUT switch bit
cm14				.btequ		4,cm1		; Low-speed on-chip oscillator stop bit
cm16				.btequ		6,cm1		; CPU clock division select bit 1
cm17				.btequ		7,cm1		; CPU clock division select bit 1
;
;-------------------------------------------------------
;   Module standby control register
;-------------------------------------------------------
mstcr			.equ		0008h
;
mstiic				.btequ		3,mstcr		; SSU, I2C bus standby bit
msttrd				.btequ		4,mstcr		; Power consumption reduce bit
msttrc				.btequ		5,mstcr		; Timer RC standby bit
;
;-------------------------------------------------------
;   System clock control register 3
;-------------------------------------------------------
cm3					.equ		0009h
;
cm30				.btequ		0,cm3		; WAIT control bit
cm35				.btequ		5,cm3		; CPU clock division when exiting wait mode select bit
cm36				.btequ		6,cm3		; System clock when exiting wait mode or stop mode select bit
cm37				.btequ		7,cm3		; System clock when exiting wait mode or stop mode select bit
;
;-------------------------------------------------------
;   Protect register
;-------------------------------------------------------
prcr				.equ		000ah
;
prc0				.btequ		0,prcr		; Protect bit 0
prc1				.btequ		1,prcr		; Protect bit 1
prc2				.btequ		2,prcr		; Protect bit 2
prc3				.btequ		3,prcr		; Protect bit 3
;
;-------------------------------------------------------
;   Reset Source Determination Register
;-------------------------------------------------------
rstfr				.equ		000bh
;
cwr					.btequ		0,rstfr		; Cold start-up/warm start-up determine flag
hwr					.btequ		1,rstfr		; Hardware reset detect flag
swr					.btequ		2,rstfr		; Software reset detect flag
wdr					.btequ		3,rstfr		; Watchdog timer reset detect flag
;
;-------------------------------------------------------
;   Oscillation stop detection register
;-------------------------------------------------------
ocd					.equ		000ch
;
ocd0				.btequ		0,ocd		; Oscillation stop detection enable bit
ocd1				.btequ		1,ocd		; Oscillation stop detection interrupt enable bit
ocd2				.btequ		2,ocd		; System clock select bit
ocd3				.btequ		3,ocd		; Clock monitor bit
;
;-------------------------------------------------------
;   Watchdog timer reset register
;-------------------------------------------------------
wdtr				.equ		000dh
;
;-------------------------------------------------------
;   Watchdog timer start register
;-------------------------------------------------------
wdts				.equ		000eh
;
;-------------------------------------------------------
;   Watchdog timer control register
;-------------------------------------------------------
wdtc				.equ		000fh
;
wdtc7				.btequ		7,wdtc		; Prescaler select bit
;
;-------------------------------------------------------
;   High-speed on-chip oscillator control register 7
;-------------------------------------------------------
fra7				.equ		0015h
;
;-------------------------------------------------------
;   Count Source Protection Mode Register
;-------------------------------------------------------
cspr				.equ		001ch
;
cspro				.btequ		7,cspr		; Count source protection mode select bit
;
;-------------------------------------------------------
;   High-speed on-chip oscillator control register 0
;-------------------------------------------------------
fra0				.equ		0023h
;
fra00				.btequ		0,fra0		; High-speed on-chip oscillator enable bit
fra01				.btequ		1,fra0		; High-speed on-chip oscillator select bit
fra03				.btequ		3,fra0		; fOCO128 clock select bit
;
;-------------------------------------------------------
;   High-speed on-chip oscillator control register 1
;-------------------------------------------------------
fra1				.equ		0024h
;
;-------------------------------------------------------
;   High-speed on-chip oscillator control register 2
;-------------------------------------------------------
fra2				.equ		0025h
;
fra20				.btequ		0,fra2		; High-speed on-chip oscillator frequency switching bit
fra21				.btequ		1,fra2		; High-speed on-chip oscillator frequency switching bit
fra22				.btequ		2,fra2		; High-speed on-chip oscillator frequency switching bit
;
;-------------------------------------------------------
;   On-Chip Reference Voltage Control Register
;-------------------------------------------------------
ocvrefcr			.equ		0026h
;
ocvrefan			.btequ		0,ocvrefcr	; On-chip reference voltage to analog input connect bit
;
;-------------------------------------------------------
;   Clock prescaler reset flag
;-------------------------------------------------------
cpsrf				.equ		0028h
;
cpsr				.btequ		7,cpsrf		; Clock prescaler reset flag
;
;-------------------------------------------------------
;   High-speed on-chip oscillator control register 4
;-------------------------------------------------------
fra4				.equ		0029h
;
;-------------------------------------------------------
;   High-speed on-chip oscillator control register 5
;-------------------------------------------------------
fra5				.equ		002Ah
;
;-------------------------------------------------------
;   High-speed on-chip oscillator control register 6
;-------------------------------------------------------
fra6				.equ		002Bh
;
;-------------------------------------------------------
;   High-speed on-chip oscillator control register 3
;-------------------------------------------------------
fra3				.equ		002Fh
;
;-------------------------------------------------------
;   Voltage Monitor Circuit Control Register
;-------------------------------------------------------
cmpa				.equ		0030h
;
irq1sel				.btequ		4,cmpa		; Voltage monitor 1 interrupt type select bit
irq2sel				.btequ		5,cmpa		; Voltage monitor 2 interrupt type select bit
compsel				.btequ		7,cmpa		; Voltage monitor interrupt type selection enable bit
;
;-------------------------------------------------------
;   Voltage monitor circuit edge select register
;-------------------------------------------------------
vcac				.equ		0031h
;
vcac1				.btequ		1,vcac		; Voltage monitor 1 circuit edge select bit
vcac2				.btequ		2,vcac		; Voltage monitor 2 circuit edge select bit
;
;-------------------------------------------------------
;   Voltage Detect Register 1
;-------------------------------------------------------
vca1				.equ		0033h
;
vca13				.btequ		3,vca1		; Voltage detection 2 signal monitor flag
;
;-------------------------------------------------------
;   Voltage Detect Register 2
;-------------------------------------------------------
vca2				.equ		0034h
;
vca20				.btequ		0,vca2		; Internal power low consumption enable bit
vca25				.btequ		5,vca2		; Voltage detection 0 enable bit
vca26				.btequ		6,vca2		; Voltage detection 1 enable bit
vca27				.btequ		7,vca2		; Voltage detection 2 enable bit
;
;-------------------------------------------------------
;   Voltage detection 1 level select register
;-------------------------------------------------------
vd1ls				.equ		0036h
;
vd1s0				.btequ		0,vd1ls		; Voltage detection 1 Level select bit
vd1s1				.btequ		1,vd1ls		; Voltage detection 1 Level select bit
vd1s2				.btequ		2,vd1ls		; Voltage detection 1 Level select bit
vd1s3				.btequ		3,vd1ls		; Voltage detection 1 Level select bit
;
;-------------------------------------------------------
;   Voltage monitor 0 circuit control register
;-------------------------------------------------------
vw0c				.equ		0038h
;
vw0c0				.btequ		0,vw0c		; Voltage monitor 0 reset enable bit
;
;-------------------------------------------------------
;   Voltage monitor 1 circuit control register
;-------------------------------------------------------
vw1c				.equ		0039h
;
vw1c0				.btequ		0,vw1c		; Voltage monitor 1 reset interrupt enable bit
vw1c1				.btequ		1,vw1c		; Voltage Monitor 1 digital filter disable mode select bit
vw1c2				.btequ		2,vw1c		; Voltage change detection flag
vw1c3				.btequ		3,vw1c		; Voltage detection 1 signal monitor flag
vw1f0				.btequ		4,vw1c		; Sampling clock select bit
vw1f1				.btequ		5,vw1c		; Sampling clock select bit
vw1c7				.btequ		7,vw1c		; Voltage monitor 1 interrupt generation condition select bit
;
;-------------------------------------------------------
;   Voltage monitor 2 circuit control register
;-------------------------------------------------------
vw2c				.equ		003Ah
;
vw2c0				.btequ		0,vw2c		; Voltage monitor 2 interrupt enable bit
vw2c1				.btequ		1,vw2c		; Voltage monitor 2 digital filter disable mode select bit
vw2c2				.btequ		2,vw2c		; Voltage change detection flag
vw2c3				.btequ		3,vw2c		; WDT detection monitor flag
vw2f0				.btequ		4,vw2c		; Sampling clock select bit
vw2f1				.btequ		5,vw2c		; Sampling clock select bit
vw2c7				.btequ		7,vw2c		; Voltage monitor 2 interrupt generation condition select bit
;
;-------------------------------------------------------
;   Flash memory ready interrupt control register
;-------------------------------------------------------
fmrdyic				.equ		0041h
;
ilvl0_fmrdyic		.btequ		0,fmrdyic	; Interrupt priority level select bit
ilvl1_fmrdyic		.btequ		1,fmrdyic	;
ilvl2_fmrdyic		.btequ		2,fmrdyic	;
ir_fmrdyic			.btequ		3,fmrdyic	; Interrupt request bit
;
;-------------------------------------------------------
;   Timer RC interrupt control register
;-------------------------------------------------------
trcic				.equ		0047h
;
ilvl0_trcic			.btequ		0,trcic		; Interrupt priority level select bit
ilvl1_trcic			.btequ		1,trcic		;
ilvl2_trcic			.btequ		2,trcic		;
ir_trcic			.btequ		3,trcic		; Interrupt request bit
;
;-------------------------------------------------------
;   Timer RE interrupt control register
;-------------------------------------------------------
treic				.equ		004Ah
;
ilvl0_treic			.btequ		0,treic		; Interrupt priority level select bit
ilvl1_treic			.btequ		1,treic		;
ilvl2_treic			.btequ		2,treic		;
ir_treic			.btequ		3,treic		; Interrupt request bit
;
;-------------------------------------------------------
;   UART2 transmit interrupt control register
;-------------------------------------------------------
s2tic				.equ		004Bh
;
ilvl0_s2tic			.btequ		0,s2tic		; Interrupt priority level select bit
ilvl1_s2tic			.btequ		1,s2tic		;
ilvl2_s2tic			.btequ		2,s2tic		;
ir_s2tic			.btequ		3,s2tic		; Interrupt request bit
;
;-------------------------------------------------------
;   UART2 receive interrupt control register
;-------------------------------------------------------
s2ric				.equ		004Ch
;
ilvl0_s2ric			.btequ		0,s2ric		; Interrupt priority level select bit
ilvl1_s2ric			.btequ		1,s2ric		;
ilvl2_s2ric			.btequ		2,s2ric		;
ir_s2ric			.btequ		3,s2ric		; Interrupt request bit
;
;-------------------------------------------------------
;   Key input interrupt control register
;-------------------------------------------------------
kupic				.equ		004dh
;
ilvl0_kupic			.btequ		0,kupic		; Interrupt priority level select bit
ilvl1_kupic			.btequ		1,kupic		;
ilvl2_kupic			.btequ		2,kupic		;
ir_kupic			.btequ		3,kupic		; Interrupt request bit
;
;-------------------------------------------------------
;   A/D conversion interrupt control register
;-------------------------------------------------------
adic				.equ		004eh
;
ilvl0_adic			.btequ		0,adic		; Interrupt priority level select bit
ilvl1_adic			.btequ		1,adic		;
ilvl2_adic			.btequ		2,adic		;
ir_adic				.btequ		3,adic		; Interrupt request bit
;
;-------------------------------------------------------
;   SSU interrupt control register
;-------------------------------------------------------
ssuic				.equ		004fh
;
ilvl0_ssuic			.btequ		0,ssuic		; Interrupt priority level select bit
ilvl1_ssuic			.btequ		1,ssuic		;
ilvl2_ssuic			.btequ		2,ssuic		;
ir_ssuic			.btequ		3,ssuic		; Interrupt request bit
;
;-------------------------------------------------------
;   IIC bus Interrupt Control Register
;-------------------------------------------------------
iicic				.equ		004fh
;
ilvl0_iicic			.btequ		0,iicic		; Interrupt priority level select bit
ilvl1_iicic			.btequ		1,iicic		;
ilvl2_iicic			.btequ		2,iicic		;
ir_iicic			.btequ		3,iicic		; Interrupt request bit
;
;-------------------------------------------------------
;   UART0 transmit interrupt control register
;-------------------------------------------------------
s0tic				.equ		0051h
;
ilvl0_s0tic			.btequ		0,s0tic		; Interrupt priority level select bit
ilvl1_s0tic			.btequ		1,s0tic		;
ilvl2_s0tic			.btequ		2,s0tic		;
ir_s0tic			.btequ		3,s0tic		; Interrupt request bit
;
;-------------------------------------------------------
;   UART0 receive interrupt control register
;-------------------------------------------------------
s0ric				.equ		0052h
;
ilvl0_s0ric			.btequ		0,s0ric		; Interrupt priority level select bit
ilvl1_s0ric			.btequ		1,s0ric		;
ilvl2_s0ric			.btequ		2,s0ric		;
ir_s0ric			.btequ		3,s0ric		; Interrupt request bit
;
;-------------------------------------------------------
;   UART1 transmit interrupt control register
;-------------------------------------------------------
s1tic				.equ		0053h
;
ilvl0_s1tic			.btequ		0,s1tic		; Interrupt priority level select bit
ilvl1_s1tic			.btequ		1,s1tic		;
ilvl2_s1tic			.btequ		2,s1tic		;
ir_s1tic			.btequ		3,s1tic		; Interrupt request bit
;
;-------------------------------------------------------
;   UART1 receive interrupt control register
;-------------------------------------------------------
s1ric				.equ		0054h
;
ilvl0_s1ric			.btequ		0,s1ric		; Interrupt priority level select bit
ilvl1_s1ric			.btequ		1,s1ric		;
ilvl2_s1ric			.btequ		2,s1ric		;
ir_s1ric			.btequ		3,s1ric		; Interrupt request bit
;
;-------------------------------------------------------
;   Timer RA interrupt control register
;-------------------------------------------------------
traic				.equ		0056h
;
ilvl0_traic			.btequ		0,traic		; Interrupt priority level select bit
ilvl1_traic			.btequ		1,traic		;
ilvl2_traic			.btequ		2,traic		;
ir_traic			.btequ		3,traic		; Interrupt request bit
;
;-------------------------------------------------------
;   Timer RB interrupt control register
;-------------------------------------------------------
trbic				.equ		0058h
;
ilvl0_trbic			.btequ		0,trbic		; Interrupt priority level select bit
ilvl1_trbic			.btequ		1,trbic		;
ilvl2_trbic			.btequ		2,trbic		;
ir_trbic			.btequ		3,trbic		; Interrupt request bit
;
;-------------------------------------------------------
;   INT1 interrupt control register
;-------------------------------------------------------
int1ic				.equ		0059h
;
ilvl0_int1ic		.btequ		0,int1ic	; Interrupt priority level select bit
ilvl1_int1ic		.btequ		1,int1ic	;
ilvl2_int1ic		.btequ		2,int1ic	;
ir_int1ic			.btequ		3,int1ic	; Interrupt request bit
pol_int1ic			.btequ		4,int1ic	; Polarity switch bit
;
;-------------------------------------------------------
;   INT3 interrupt control register
;-------------------------------------------------------
int3ic				.equ		005ah
;
ilvl0_int3ic		.btequ		0,int3ic	; Interrupt priority level select bit
ilvl1_int3ic		.btequ		1,int3ic	;
ilvl2_int3ic		.btequ		2,int3ic	;
ir_int3ic			.btequ		3,int3ic	; Interrupt request bit
pol_int3ic			.btequ		4,int3ic	; Polarity switch bit
;
;-------------------------------------------------------
;   INT0 interrupt control register
;-------------------------------------------------------
int0ic				.equ		005dh
;
ilvl0_int0ic		.btequ		0,int0ic	; Interrupt priority level select bit
ilvl1_int0ic		.btequ		1,int0ic	;
ilvl2_int0ic		.btequ		2,int0ic	;
ir_int0ic			.btequ		3,int0ic	; Interrupt request bit
pol_int0ic			.btequ		4,int0ic	; Polarity switch bit
;
;-------------------------------------------------------
;   UART2 bus collision detection interrupt control register
;-------------------------------------------------------
u2bcnic				.equ		005Eh
;
ilvl0_u2bcnic		.btequ		0,u2bcnic	; Interrupt priority level select bit
ilvl1_u2bcnic		.btequ		1,u2bcnic	;
ilvl2_u2bcnic		.btequ		2,u2bcnic	;
ir_u2bcnic			.btequ		3,u2bcnic	; Interrupt request bit
;
;-------------------------------------------------------
;   Voltage Monitor 1 Interrupt Control Register
;-------------------------------------------------------
vcmp1ic				.equ		0072h
;
ilvl0_vcmp1ic		.btequ		0,vcmp1ic	; Interrupt priority level select bit
ilvl1_vcmp1ic		.btequ		1,vcmp1ic	;
ilvl2_vcmp1ic		.btequ		2,vcmp1ic	;
ir_vcmp1ic			.btequ		3,vcmp1ic	; Interrupt request bit
;
;-------------------------------------------------------
;   Voltage Monitor 2 Interrupt Control Register
;-------------------------------------------------------
vcmp2ic				.equ		0073h
;
ilvl0_vcmp2ic		.btequ		0,vcmp2ic	; Interrupt priority level select bit
ilvl1_vcmp2ic		.btequ		1,vcmp2ic	;
ilvl2_vcmp2ic		.btequ		2,vcmp2ic	;
ir_vcmp2ic			.btequ		3,vcmp2ic	; Interrupt request bit
;
;-------------------------------------------------------
;   DTC Activation Control Register
;-------------------------------------------------------
dtctl				.equ		0080h
;
nmif				.btequ		1,dtctl		; Non-maskable interrupt generation bit
;
;-------------------------------------------------------
;   DTC Activation Enable Register 0
;-------------------------------------------------------
dtcen0				.equ		0088h
;
dtcen00				.btequ		0,dtcen0	; DTC activation enable bit
dtcen01				.btequ		1,dtcen0	; DTC activation enable bit
dtcen02				.btequ		2,dtcen0	; DTC activation enable bit
dtcen03				.btequ		3,dtcen0	; DTC activation enable bit
dtcen04				.btequ		4,dtcen0	; DTC activation enable bit
dtcen05				.btequ		5,dtcen0	; DTC activation enable bit
dtcen06				.btequ		6,dtcen0	; DTC activation enable bit
dtcen07				.btequ		7,dtcen0	; DTC activation enable bit
;
;-------------------------------------------------------
;   DTC Activation Enable Register 1
;-------------------------------------------------------
dtcen1				.equ		0089h
;
dtcen10				.btequ		0,dtcen1	; DTC activation enable bit
dtcen11				.btequ		1,dtcen1	; DTC activation enable bit
dtcen12				.btequ		2,dtcen1	; DTC activation enable bit
dtcen13				.btequ		3,dtcen1	; DTC activation enable bit
dtcen14				.btequ		4,dtcen1	; DTC activation enable bit
dtcen15				.btequ		5,dtcen1	; DTC activation enable bit
dtcen16				.btequ		6,dtcen1	; DTC activation enable bit
dtcen17				.btequ		7,dtcen1	; DTC activation enable bit
;
;-------------------------------------------------------
;   DTC Activation Enable Register 2
;-------------------------------------------------------
dtcen2				.equ		008Ah
;
dtcen20				.btequ		0,dtcen2	; DTC activation enable bit
dtcen21				.btequ		1,dtcen2	; DTC activation enable bit
dtcen22				.btequ		2,dtcen2	; DTC activation enable bit
dtcen23				.btequ		3,dtcen2	; DTC activation enable bit
dtcen24				.btequ		4,dtcen2	; DTC activation enable bit
dtcen25				.btequ		5,dtcen2	; DTC activation enable bit
dtcen26				.btequ		6,dtcen2	; DTC activation enable bit
dtcen27				.btequ		7,dtcen2	; DTC activation enable bit
;
;-------------------------------------------------------
;   DTC Activation Enable Register 3
;-------------------------------------------------------
dtcen3				.equ		008Bh
;
dtcen30				.btequ		0,dtcen3	; DTC activation enable bit
dtcen31				.btequ		1,dtcen3	; DTC activation enable bit
dtcen32				.btequ		2,dtcen3	; DTC activation enable bit
dtcen33				.btequ		3,dtcen3	; DTC activation enable bit
dtcen34				.btequ		4,dtcen3	; DTC activation enable bit
dtcen35				.btequ		5,dtcen3	; DTC activation enable bit
dtcen36				.btequ		6,dtcen3	; DTC activation enable bit
dtcen37				.btequ		7,dtcen3	; DTC activation enable bit
;
;-------------------------------------------------------
;   DTC Activation Enable Register 5
;-------------------------------------------------------
dtcen5				.equ		008Dh
;
dtcen50				.btequ		0,dtcen5	; DTC activation enable bit
dtcen51				.btequ		1,dtcen5	; DTC activation enable bit
dtcen52				.btequ		2,dtcen5	; DTC activation enable bit
dtcen53				.btequ		3,dtcen5	; DTC activation enable bit
dtcen54				.btequ		4,dtcen5	; DTC activation enable bit
dtcen55				.btequ		5,dtcen5	; DTC activation enable bit
dtcen56				.btequ		6,dtcen5	; DTC activation enable bit
dtcen57				.btequ		7,dtcen5	; DTC activation enable bit
;
;-------------------------------------------------------
;   DTC Activation Enable Register 6
;-------------------------------------------------------
dtcen6				.equ		008Eh
;
dtcen60				.btequ		0,dtcen6	; DTC activation enable bit
dtcen61				.btequ		1,dtcen6	; DTC activation enable bit
dtcen62				.btequ		2,dtcen6	; DTC activation enable bit
dtcen63				.btequ		3,dtcen6	; DTC activation enable bit
dtcen64				.btequ		4,dtcen6	; DTC activation enable bit
dtcen65				.btequ		5,dtcen6	; DTC activation enable bit
dtcen66				.btequ		6,dtcen6	; DTC activation enable bit
dtcen67				.btequ		7,dtcen6	; DTC activation enable bit
;
;-------------------------------------------------------
;   UART0 transmit/receive mode register
;-------------------------------------------------------
u0mr				.equ		00a0h
;
smd0_u0mr			.btequ		0,u0mr		; Serial I/O mode select bit
smd1_u0mr			.btequ		1,u0mr		; Serial I/O mode select bit
smd2_u0mr			.btequ		2,u0mr		; Serial I/O mode select bit
ckdir_u0mr			.btequ		3,u0mr		; Internal/external clock select bit
stps_u0mr			.btequ		4,u0mr		; Stop bit length select bit
pry_u0mr			.btequ		5,u0mr		; Odd/even parity select bit
prye_u0mr			.btequ		6,u0mr		; Parity enable bit
;
;-------------------------------------------------------
;   UART0 bit rate register
;-------------------------------------------------------
u0brg				.equ		00a1h
;
;-------------------------------------------------------
;   UART0 transmit buffer register
;-------------------------------------------------------
u0tb				.equ		00a2h
;
u0tbl				.equ		u0tb		;       Low
u0tbh				.equ		u0tb+1		;       High
;
;-------------------------------------------------------
;   UART0 Transmit/Receive Control Register 0
;-------------------------------------------------------
u0c0				.equ		00a4h
;
clk0_u0c0			.btequ		0,u0c0		; BRG count source select bit
clk1_u0c0			.btequ		1,u0c0		; BRG count source select bit
txept_u0c0			.btequ		3,u0c0		; Transmit register empty flag
nch_u0c0			.btequ		5,u0c0		; Data output select bit
ckpol_u0c0			.btequ		6,u0c0		; CLK polarity select bit
uform_u0c0			.btequ		7,u0c0		; Transfer format select bit
;
;-------------------------------------------------------
;   UART0 Transmit/Receive Control Register 1
;-------------------------------------------------------
u0c1				.equ		00a5h
;
te_u0c1				.btequ		0,u0c1		; Transmit enable bit
ti_u0c1				.btequ		1,u0c1		; Transmit buffer empty flag
re_u0c1				.btequ		2,u0c1		; Receive enable bit
ri_u0c1				.btequ		3,u0c1		; Receive complete flag
u0irs_u0c1			.btequ		4,u0c1		; UART0 transmit interrupt source select bit
u0rrm_u0c1			.btequ		5,u0c1		; UART0 continuous receive mode enable bit
;
;-------------------------------------------------------
;   UART0 receive buffer register
;-------------------------------------------------------
u0rb				.equ		00a6h
;
u0rbl				.equ		u0rb		;       Low
u0rbh				.equ		u0rb+1		;       High
oer_u0rb			.btequ		4,u0rbh		; Overrun error flag
fer_u0rb			.btequ		5,u0rbh		; Framing error flag
per_u0rb			.btequ		6,u0rbh		; Parity error flag
sum_u0rb			.btequ		7,u0rbh		; Error sum flag
;
;-------------------------------------------------------
;   UART2 transmit/receive mode register
;-------------------------------------------------------
u2mr				.equ		00a8h
;
smd0_u2mr			.btequ		0,u2mr		; Serial I/O mode select bit
smd1_u2mr			.btequ		1,u2mr		; Serial I/O mode select bit
smd2_u2mr			.btequ		2,u2mr		; Serial I/O mode select bit
ckdir_u2mr			.btequ		3,u2mr		; Internal/external clock select bit
stps_u2mr			.btequ		4,u2mr		; Stop bit length select bit
pry_u2mr			.btequ		5,u2mr		; Odd/even parity select bit
prye_u2mr			.btequ		6,u2mr		; Parity enable bit
iopol_u2mr			.btequ		7,u2mr		; TXD, RXD I/O polarity switch bit
;
;-------------------------------------------------------
;   UART2 bit rate register
;-------------------------------------------------------
u2brg				.equ		00a9h
;
;-------------------------------------------------------
;   UART2 transmit buffer register
;-------------------------------------------------------
u2tb				.equ		00aah
;
u2tbl				.equ		u2tb		;       Low
u2tbh				.equ		u2tb+1		;       High
mptb_u2tb			.btequ		0,u2tbh		; Transmit data
;
;-------------------------------------------------------
;   UART2 Transmit/Receive Control Register 0
;-------------------------------------------------------
u2c0				.equ		00ach
;
clk0_u2c0			.btequ		0,u2c0		; U2BRG count source select bit
clk1_u2c0			.btequ		1,u2c0		; U2BRG count source select bit
crs_u2c0			.btequ		2,u2c0		; CTS/RTS function select bit
txept_u2c0			.btequ		3,u2c0		; Transmit register empty flag
crd_u2c0			.btequ		4,u2c0		; CTS/RTS disable bit
nch_u2c0			.btequ		5,u2c0		; Data output select bit
ckpol_u2c0			.btequ		6,u2c0		; CLK polarity select bit
uform_u2c0			.btequ		7,u2c0		; Transfer format select bit
;
;-------------------------------------------------------
;   UART2 Transmit/Receive Control Register 1
;-------------------------------------------------------
u2c1				.equ		00adh
;
te_u2c1				.btequ		0,u2c1		; Transmit enable bit
ti_u2c1				.btequ		1,u2c1		; Transmit buffer empty flag
re_u2c1				.btequ		2,u2c1		; Receive enable bit
ri_u2c1				.btequ		3,u2c1		; Receive complete flag
u2irs_u2c1			.btequ		4,u2c1		; UART2 transmit interrupt source select bit
u2rrm_u2c1			.btequ		5,u2c1		; UART2 continuous receive mode enable bit
u2lch_u2c1			.btequ		6,u2c1		; Data logic select bit
u2ere_u2c1			.btequ		7,u2c1		; Error signal output enable bit
;
;-------------------------------------------------------
;   UART2 receive buffer register
;-------------------------------------------------------
u2rb				.equ		00aeh
;
u2rbl				.equ		u2rb		;       Low
u2rbh				.equ		u2rb+1		;       High
mprb_u2rb			.btequ		0,u2rbh		; Receive data
oer_u2rb			.btequ		4,u2rbh		; Overrun error flag
fer_u2rb			.btequ		5,u2rbh		; Framing error flag
per_u2rb			.btequ		6,u2rbh		; Parity error flag
sum_u2rb			.btequ		7,u2rbh		; Error sum flag
;
;-------------------------------------------------------
;   UART2 Digital Filter Function Select Register
;-------------------------------------------------------
urxdf				.equ		00B0h
;
df2en				.btequ		2,urxdf		; RXD2 digital filter enable bit
;
;-------------------------------------------------------
;   UART2 special mode register 5
;-------------------------------------------------------
u2smr5				.equ		00BBh
;
mp					.btequ		0,u2smr5	; Multiprocessor Communication enable bit
mpie				.btequ		4,u2smr5	; Multiprocessor Communication control bit
;
;-------------------------------------------------------
;   UART2 special mode register 4
;-------------------------------------------------------
u2smr4				.equ		00BCh
;
stareq				.btequ		0,u2smr4	; Start condition generate bit
rstareq				.btequ		1,u2smr4	; Restart condition generate bit
stpreq				.btequ		2,u2smr4	; Stop condition generate bit
stspsel				.btequ		3,u2smr4	; SCL, SDA output select bit
ackd				.btequ		4,u2smr4	; ACK data bit
ackc				.btequ		5,u2smr4	; ACK data output enable bit
sclhi				.btequ		6,u2smr4	; SCL output stop enable bit
swc9				.btequ		7,u2smr4	; SCL wait bit 3
;
;-------------------------------------------------------
;   UART2 special mode register 3
;-------------------------------------------------------
u2smr3				.equ		00BDh
;
ckph				.btequ		1,u2smr3	; Clock phase set bit
nodc				.btequ		3,u2smr3	; Clock output select bit
dl0					.btequ		5,u2smr3	; SDA2 digital delay setup bit
dl1					.btequ		6,u2smr3	; SDA2 digital delay setup bit
dl2					.btequ		7,u2smr3	; SDA2 digital delay setup bit
;
;-------------------------------------------------------
;   UART2 special mode register 2
;-------------------------------------------------------
u2smr2				.equ		00BEh
;
iicm2				.btequ		0,u2smr2	; I2C mode select bit 2
csc					.btequ		1,u2smr2	; Clock synchronization bit
swc					.btequ		2,u2smr2	; SCL wait output bit
stac				.btequ		4,u2smr2	; UART2 initialization bit
swc2				.btequ		5,u2smr2	; SCL wait output bit 2
sdhi				.btequ		6,u2smr2	; SDA output disable bit
;
;-------------------------------------------------------
;   UART2 special mode register
;-------------------------------------------------------
u2smr				.equ		00BFh
;
iicm				.btequ		0,u2smr		; I2C mode select bit
bbs					.btequ		2,u2smr		; Bus busy flag
;
;-------------------------------------------------------
;   A/D Register 0
;-------------------------------------------------------
ad0					.equ		00c0h
;
ad0l				.equ		ad0			;       Low
ad0h				.equ		ad0+1		;       High
;
;-------------------------------------------------------
;   A/D Register 1
;-------------------------------------------------------
ad1					.equ		00c2h
;
ad1l				.equ		ad1			;       Low
ad1h				.equ		ad1+1		;       High
;
;-------------------------------------------------------
;   A/D Register 2
;-------------------------------------------------------
ad2					.equ		00c4h
;
ad2l				.equ		ad2			;       Low
ad2h				.equ		ad2+1		;       High
;
;-------------------------------------------------------
;   A/D Register 3
;-------------------------------------------------------
ad3					.equ		00c6h
;
ad3l				.equ		ad3			;       Low
ad3h				.equ		ad3+1		;       High
;
;-------------------------------------------------------
;   A/D Register 4
;-------------------------------------------------------
ad4					.equ		00c8h
;
ad4l				.equ		ad4			;       Low
ad4h				.equ		ad4+1		;       High
;
;-------------------------------------------------------
;   A/D Register 5
;-------------------------------------------------------
ad5					.equ		00cAh
;
ad5l				.equ		ad5			;       Low
ad5h				.equ		ad5+1		;       High
;
;-------------------------------------------------------
;   A/D Register 6
;-------------------------------------------------------
ad6					.equ		00cCh
;
ad6l				.equ		ad6			;       Low
ad6h				.equ		ad6+1		;       High
;
;-------------------------------------------------------
;   A/D Register 7
;-------------------------------------------------------
ad7					.equ		00cEh
;
ad7l				.equ		ad7			;       Low
ad7h				.equ		ad7+1		;       High
;
;-------------------------------------------------------
;   A/D mode register
;-------------------------------------------------------
admod				.equ		00D4h
;
cks0				.btequ		0,admod		; Division select bit
cks1				.btequ		1,admod		; Division select bit
cks2				.btequ		2,admod		; Clock source select bit
md0					.btequ		3,admod		; A/D operating mode select bit
md1					.btequ		4,admod		; A/D operating mode select bit
md2					.btequ		5,admod		; A/D operating mode select bit
adcap0				.btequ		6,admod		; A/D conversion trigger select bit
adcap1				.btequ		7,admod		; A/D conversion trigger select bit
;
;-------------------------------------------------------
;   A/D input select register
;-------------------------------------------------------
adinsel				.equ		00D5h
;
ch0					.btequ		0,adinsel	; Analog input pin select bit
ch1					.btequ		1,adinsel	; Analog input pin select bit
ch2					.btequ		2,adinsel	; Analog input pin select bit
scan0				.btequ		4,adinsel	; A/D sweep pin count select bit
scan1				.btequ		5,adinsel	; A/D sweep pin count select bit
adgsel0				.btequ		6,adinsel	; A/D input group select bit
adgsel1				.btequ		7,adinsel	; A/D input group select bit
;
;-------------------------------------------------------
;   A/D Control Register 0
;-------------------------------------------------------
adcon0				.equ		00d6h
;
adst				.btequ		0,adcon0	; A/D conversion start flag
;
;-------------------------------------------------------
;   A/D Control Register 1
;-------------------------------------------------------
adcon1				.equ		00d7h
;
adex0				.btequ		0,adcon1	; Extended analog input pin select bit
bits				.btequ		4,adcon1	; 8/10-bit mode select bit
adstby				.btequ		5,adcon1	; A/D standby bit
adddaen				.btequ		6,adcon1	; A/D open-circuit detection assist function enable bit
adddael				.btequ		7,adcon1	; A/D open-circuit detection assist method select bit
;
;-------------------------------------------------------
;   D/A0 Register
;-------------------------------------------------------
da0					.equ		00d8h
;
;-------------------------------------------------------
;   D/A1 Register
;-------------------------------------------------------
da1					.equ		00d9h
;
;-------------------------------------------------------
;   D/A Control Register
;-------------------------------------------------------
dacon				.equ		00dch
;
da0e_dacon			.btequ		0,dacon		; D/A0 output enable bit
da1e_dacon			.btequ		1,dacon		; D/A1 output enable bit
;
;-------------------------------------------------------
;   Port P0 Register
;-------------------------------------------------------
p0					.equ		00e0h
;
p0_0				.btequ		0,p0		; Port P0_0 bit
p0_1				.btequ		1,p0		; Port P0_1 bit
p0_2				.btequ		2,p0		; Port P0_2 bit
p0_3				.btequ		3,p0		; Port P0_3 bit
p0_4				.btequ		4,p0		; Port P0_4 bit
p0_5				.btequ		5,p0		; Port P0_5 bit
p0_6				.btequ		6,p0		; Port P0_6 bit
p0_7				.btequ		7,p0		; Port P0_7 bit
;
;-------------------------------------------------------
;   Port P1 Register
;-------------------------------------------------------
p1					.equ		00e1h
;
p1_0				.btequ		0,p1		; Port P1_0 bit
p1_1				.btequ		1,p1		; Port P1_1 bit
p1_2				.btequ		2,p1		; Port P1_2 bit
p1_3				.btequ		3,p1		; Port P1_3 bit
p1_4				.btequ		4,p1		; Port P1_4 bit
p1_5				.btequ		5,p1		; Port P1_5 bit
p1_6				.btequ		6,p1		; Port P1_6 bit
p1_7				.btequ		7,p1		; Port P1_7 bit
;
;-------------------------------------------------------
;   Port P0 Direction Register
;-------------------------------------------------------
pd0					.equ		00e2h
;
pd0_0				.btequ		0,pd0		; Port P0_0 direction bit
pd0_1				.btequ		1,pd0		; Port P0_1 direction bit
pd0_2				.btequ		2,pd0		; Port P0_2 direction bit
pd0_3				.btequ		3,pd0		; Port P0_3 direction bit
pd0_4				.btequ		4,pd0		; Port P0_4 direction bit
pd0_5				.btequ		5,pd0		; Port P0_5 direction bit
pd0_6				.btequ		6,pd0		; Port P0_6 direction bit
pd0_7				.btequ		7,pd0		; Port P0_7 direction bit
;
;-------------------------------------------------------
;   Port P1 Direction Register
;-------------------------------------------------------
pd1					.equ		00e3h
;
pd1_0				.btequ		0,pd1		; Port P1_0 direction bit
pd1_1				.btequ		1,pd1		; Port P1_1 direction bit
pd1_2				.btequ		2,pd1		; Port P1_2 direction bit
pd1_3				.btequ		3,pd1		; Port P1_3 direction bit
pd1_4				.btequ		4,pd1		; Port P1_4 direction bit
pd1_5				.btequ		5,pd1		; Port P1_5 direction bit
pd1_6				.btequ		6,pd1		; Port P1_6 direction bit
pd1_7				.btequ		7,pd1		; Port P1_7 direction bit
;
;-------------------------------------------------------
;   Port P2 Register
;-------------------------------------------------------
p2					.equ		00e4h
;
p2_0				.btequ		0,p2		; Port P2_0 bit
p2_1				.btequ		1,p2		; Port P2_1 bit
p2_2				.btequ		2,p2		; Port P2_2 bit
;
;-------------------------------------------------------
;   Port P3 Register
;-------------------------------------------------------
p3					.equ		00e5h
;
p3_1				.btequ		1,p3		; Port P3_1 bit
p3_3				.btequ		3,p3		; Port P3_3 bit
p3_4				.btequ		4,p3		; Port P3_4 bit
p3_5				.btequ		5,p3		; Port P3_5 bit
p3_7				.btequ		7,p3		; Port P3_7 bit
;
;-------------------------------------------------------
;   Port P2 Direction Register
;-------------------------------------------------------
pd2					.equ		00e6h
;
pd2_0				.btequ		0,pd2		; Port P2_0 direction bit
pd2_1				.btequ		1,pd2		; Port P2_1 direction bit
pd2_2				.btequ		2,pd2		; Port P2_2 direction bit
;
;-------------------------------------------------------
;   Port P3 Direction Register
;-------------------------------------------------------
pd3					.equ		00e7h
;
pd3_1				.btequ		1,pd3		; Port P3_1 direction bit
pd3_3				.btequ		3,pd3		; Port P3_3 direction bit
pd3_4				.btequ		4,pd3		; Port P3_4 direction bit
pd3_5				.btequ		5,pd3		; Port P3_5 direction bit
pd3_7				.btequ		7,pd3		; Port P3_7 direction bit
;
;-------------------------------------------------------
;   Port P4 Register
;-------------------------------------------------------
p4					.equ		00e8h
;
p4_2				.btequ		2,p4		; Port P4_2 bit
p4_5				.btequ		5,p4		; Port P4_5 bit
p4_6				.btequ		6,p4		; Port P4_6 bit
p4_7				.btequ		7,p4		; Port P4_7 bit
;
;-------------------------------------------------------
;   Port P4 Direction Register
;-------------------------------------------------------
pd4					.equ		00eah
;
pd4_5				.btequ		5,pd4		; Port P4_5 direction bit
pd4_6				.btequ		6,pd4		; Port P4_6 direction bit
pd4_7				.btequ		7,pd4		; Port P4_7 direction bit
;
;-------------------------------------------------------
;   Timer RA Control Register
;-------------------------------------------------------
tracr				.equ		0100h
;
tstart_tracr		.btequ		0,tracr		; Timer RA count start bit
tcstf_tracr			.btequ		1,tracr		; Timer RA count status flag
tstop_tracr			.btequ		2,tracr		; Timer RA count forcible stop bit
tedgf_tracr			.btequ		4,tracr		; Active edge judgment flag
tundf_tracr			.btequ		5,tracr		; Timer RA underflow flag
;
;-------------------------------------------------------
;   Timer RA I/O Control Register
;-------------------------------------------------------
traioc				.equ		0101h
;
tedgsel_traioc		.btequ		0,traioc	; TRAIO polarity switch bit
topcr_traioc		.btequ		1,traioc	; TRAIO output control bit
toena_traioc		.btequ		2,traioc	; TRAO output enable bit
tiosel_traioc		.btequ		3,traioc	; Hardware LIN function select bit
tipf0_traioc		.btequ		4,traioc	; TRAIO input filter select bit
tipf1_traioc		.btequ		5,traioc	; TRAIO input filter select bit
tiogt0_traioc		.btequ		6,traioc	; TRAIO event input control bit
tiogt1_traioc		.btequ		7,traioc	; TRAIO event input control bit
;
;-------------------------------------------------------
;   Timer RA Mode Register
;-------------------------------------------------------
tramr				.equ		0102h
;
tmod0_tramr			.btequ		0,tramr		; Timer RA operating mode select bit
tmod1_tramr			.btequ		1,tramr		; Timer RA operating mode select bit
tmod2_tramr			.btequ		2,tramr		; Timer RA operating mode select bit
tck0_tramr			.btequ		4,tramr		; Timer RA count source select bit
tck1_tramr			.btequ		5,tramr		; Timer RA count source select bit
tck2_tramr			.btequ		6,tramr		; Timer RA count source select bit
tckcut_tramr		.btequ		7,tramr		; Timer RA count source cutoff bit
;
;-------------------------------------------------------
;   Timer RA prescaler register
;-------------------------------------------------------
trapre				.equ		0103h
;
;-------------------------------------------------------
;   Timer RA register
;-------------------------------------------------------
tra					.equ		0104h
;
;-------------------------------------------------------
;   LIN Control Register 2
;-------------------------------------------------------
lincr2				.equ		0105h
;
bce_lincr2			.btequ		0,lincr2	; Bus collision detection during Sync Break transmission enable bit
;
;-------------------------------------------------------
;   LIN control register
;-------------------------------------------------------
lincr				.equ		0106h
;
sfie_lincr			.btequ		0,lincr		; Synch Field measurement-completed interrupt enable bit
sbie_lincr			.btequ		1,lincr		; Synch Break detection interrupt enable bit
bcie_lincr			.btequ		2,lincr		; Bus collision detection interrupt enable bit
rxdsf_lincr			.btequ		3,lincr		; RxD0 input status flag
lstart_lincr		.btequ		4,lincr		; Synch Break detection start bit
sbe_lincr			.btequ		5,lincr		; RxD0 input unmasking timing select bit
mst_lincr			.btequ		6,lincr		; LIN operation mode setting bit
line_lincr			.btequ		7,lincr		; LIN operation start bit
;
;-------------------------------------------------------
;   LIN status register
;-------------------------------------------------------
linst				.equ		0107h
;
sfdct_linst			.btequ		0,linst		; Synch Field measurement-completed flag
sbdct_linst			.btequ		1,linst		; Synch Break detection flag
bcdct_linst			.btequ		2,linst		; Bus collision detection flag
b0clr_linst			.btequ		3,linst		; SFDCT bit clear bit
b1clr_linst			.btequ		4,linst		; SBDCT bit clear bit
b2clr_linst			.btequ		5,linst		; BCDCT bit clear bit
;
;-------------------------------------------------------
;   Timer RB Control Register
;-------------------------------------------------------
trbcr				.equ		0108h
;
tstart_trbcr		.btequ		0,trbcr		; Timer RB count start bit
tcstf_trbcr			.btequ		1,trbcr		; Timer RB count status flag
tstop_trbcr			.btequ		2,trbcr		; Timer RB count forcible stop bit
;
;-------------------------------------------------------
;   Timer RB One-Shot Control Register
;-------------------------------------------------------
trbocr				.equ		0109h
;
tosst_trbocr		.btequ		0,trbocr	; Timer RB one-shot start bit
tossp_trbocr		.btequ		1,trbocr	; Timer RB one-shot stop bit
tosstf_trbocr		.btequ		2,trbocr	; Timer RB one-shot status flag
;
;-------------------------------------------------------
;   Timer RB I/O Control Register
;-------------------------------------------------------
trbioc				.equ		010Ah
;
topl_trbioc			.btequ		0,trbioc	; Timer RB output level select bit
tocnt_trbioc		.btequ		1,trbioc	; Timer RB output switch bit
inostg_trbioc		.btequ		2,trbioc	; One-shot trigger control bit
inoseg_trbioc		.btequ		3,trbioc	; One-shot trigger polarity select bit
;
;-------------------------------------------------------
;   Timer RB Mode Register
;-------------------------------------------------------
trbmr				.equ		010Bh
;
tmod0_trbmr			.btequ		0,trbmr		; Timer RB operating mode select bit
tmod1_trbmr			.btequ		1,trbmr		; Timer RB operating mode select bit
twrc_trbmr			.btequ		3,trbmr		; Timer RB write control bit
tck0_trbmr			.btequ		4,trbmr		; Timer RB count source select bit
tck1_trbmr			.btequ		5,trbmr		; Timer RB count source select bit
tckcut_trbmr		.btequ		7,trbmr		; Timer RB count source cutoff bit
;
;-------------------------------------------------------
;   Timer RB prescaler register
;-------------------------------------------------------
trbpre				.equ		010ch
;
;-------------------------------------------------------
;   Timer RB secondary register
;-------------------------------------------------------
trbsc				.equ		010dh
;
;-------------------------------------------------------
;   Timer RB primary register
;-------------------------------------------------------
trbpr				.equ		010eh
;
;-------------------------------------------------------
;   Timer RE Second Data Register / Counter Data Register
;-------------------------------------------------------
tresec				.equ		0118h
;
sc00_tresec			.btequ		0,tresec	; 1st digit of second count bit
sc01_tresec			.btequ		1,tresec	; 1st digit of second count bit
sc02_tresec			.btequ		2,tresec	; 1st digit of second count bit
sc03_tresec			.btequ		3,tresec	; 1st digit of second count bit
sc10_tresec			.btequ		4,tresec	; 2nd digit of second count bit
sc11_tresec			.btequ		5,tresec	; 2nd digit of second count bit
sc12_tresec			.btequ		6,tresec	; 2nd digit of second count bit
bsy_tresec			.btequ		7,tresec	; Timer RE busy flag
;
;-------------------------------------------------------
;   Timer RE Minute Data Register / Compare Data Register
;-------------------------------------------------------
tremin				.equ		0119h
;
mn00_tremin			.btequ		0,tremin	; 1st digit of minute count bit
mn01_tremin			.btequ		1,tremin	; 1st digit of minute count bit
mn02_tremin			.btequ		2,tremin	; 1st digit of minute count bit
mn03_tremin			.btequ		3,tremin	; 1st digit of minute count bit
mn10_tremin			.btequ		4,tremin	; 2nd digit of minute count bit
mn11_tremin			.btequ		5,tremin	; 2nd digit of minute count bit
mn12_tremin			.btequ		6,tremin	; 2nd digit of minute count bit
bsy_tremin			.btequ		7,tremin	; Timer RE busy flag
;
;-------------------------------------------------------
;   Timer RE Hour Data Register
;-------------------------------------------------------
trehr				.equ		011ah
;
hr00_trehr			.btequ		0,trehr		; 1st digit of hour count bit
hr01_trehr			.btequ		1,trehr		; 1st digit of hour count bit
hr02_trehr			.btequ		2,trehr		; 1st digit of hour count bit
hr03_trehr			.btequ		3,trehr		; 1st digit of hour count bit
hr10_trehr			.btequ		4,trehr		; 2nd digit of hour count bit
hr11_trehr			.btequ		5,trehr		; 2nd digit of hour count bit
bsy_trehr			.btequ		7,trehr		; Timer RE busy flag
;
;-------------------------------------------------------
;   Timer RE Day of Week Data Register
;-------------------------------------------------------
trewk				.equ		011bh
;
wk0_trewk			.btequ		0,trewk		; Day of week count bit
wk1_trewk			.btequ		1,trewk		; Day of week count bit
wk2_trewk			.btequ		2,trewk		; Day of week count bit
bsy_trewk			.btequ		7,trewk		; Timer RE busy flag
;
;-------------------------------------------------------
;   Timer RE Control Register 1
;-------------------------------------------------------
trecr1				.equ		011ch
;
tcstf_trecr1		.btequ		1,trecr1	; Timer RE count status flag
toena_trecr1		.btequ		2,trecr1	; TREO pin output enable bit
int_trecr1			.btequ		3,trecr1	; Interrupt request timing bit
trerst_trecr1		.btequ		4,trecr1	; Timer RE reset bit
pm_trecr1			.btequ		5,trecr1	; A.m./p.m. bit
h12_h24_trecr1		.btequ		6,trecr1	; Operating mode select bit
tstart_trecr1		.btequ		7,trecr1	; Timer RE count start bit
;
;-------------------------------------------------------
;   Timer RE Control Register 2
;-------------------------------------------------------
trecr2				.equ		011dh
;
seie_trecr2			.btequ		0,trecr2	; Periodic interrupt triggered every second enable bit
mnie_trecr2			.btequ		1,trecr2	; Periodic interrupt triggered every minute enable bit
hrie_trecr2			.btequ		2,trecr2	; Periodic interrupt triggered every hour enable bit
dyie_trecr2			.btequ		3,trecr2	; Periodic interrupt triggered every day enable bit
wkie_trecr2			.btequ		4,trecr2	; Periodic interrupt triggered every week enable bit
comie_trecr2		.btequ		5,trecr2	; Compare match interrupt enable bit
;
;-------------------------------------------------------
;   Timer RE Count Source Select Register
;-------------------------------------------------------
trecsr				.equ		011eh
;
rcs0_trecsr			.btequ		0,trecsr	; Count source select bit
rcs1_trecsr			.btequ		1,trecsr	; Count source select bit
rcs2_trecsr			.btequ		2,trecsr	; 4-Bit counter select bit
rcs3_trecsr			.btequ		3,trecsr	; Real-Time clock mode select bit
rcs4_trecsr			.btequ		4,trecsr	; Clock output select bit
rcs5_trecsr			.btequ		5,trecsr	; Clock output select bit
rcs6_trecsr			.btequ		6,trecsr	; Clock output select bit
;
;-------------------------------------------------------
;   Timer RC Mode Register
;-------------------------------------------------------
trcmr				.equ		0120h
;
pwmb_trcmr			.btequ		0,trcmr		; PWM mode of TRCIOB select bit
pwmc_trcmr			.btequ		1,trcmr		; PWM mode of TRCIOC select bit
pwmd_trcmr			.btequ		2,trcmr		; PWM mode of TRCIOD select bit
pwm2_trcmr			.btequ		3,trcmr		; PWM2 mode select bit
bfc_trcmr			.btequ		4,trcmr		; TRCGRC register function select bit
bfd_trcmr			.btequ		5,trcmr		; TRCGRD register function select bit
tstart_trcmr		.btequ		7,trcmr		; TRC count start bit
;
;-------------------------------------------------------
;   Timer RC Control Register 1
;-------------------------------------------------------
trccr1				.equ		0121h
;
toa_trccr1			.btequ		0,trccr1	; TRCIOA output level select bit
tob_trccr1			.btequ		1,trccr1	; TRCIOB output level select bit
toc_trccr1			.btequ		2,trccr1	; TRCIOC output level select bit
tod_trccr1			.btequ		3,trccr1	; TRCIOD output level select bit
tck0_trccr1			.btequ		4,trccr1	; Count source select bit
tck1_trccr1			.btequ		5,trccr1	; Count source select bit
tck2_trccr1			.btequ		6,trccr1	; Count source select bit
cclr_trccr1			.btequ		7,trccr1	; TRC counter clear select bit
;
;-------------------------------------------------------
;   Timer RC Interrupt Enable Register
;-------------------------------------------------------
trcier				.equ		0122h
;
imiea_trcier		.btequ		0,trcier	; Input capture / compare match interrupt enable bit A
imieb_trcier		.btequ		1,trcier	; Input capture / compare match interrupt enable bit B
imiec_trcier		.btequ		2,trcier	; Input capture / compare match interrupt enable bit C
imied_trcier		.btequ		3,trcier	; Input capture / compare match interrupt enable bit D
ovie_trcier			.btequ		7,trcier	; Overflow interrupt enable bit
;
;-------------------------------------------------------
;   Timer RC Status Register
;-------------------------------------------------------
trcsr				.equ		0123h
;
imfa_trcsr			.btequ		0,trcsr		; Input capture / compare match flag A
imfb_trcsr			.btequ		1,trcsr		; Input capture / compare match flag B
imfc_trcsr			.btequ		2,trcsr		; Input capture / compare match flag C
imfd_trcsr			.btequ		3,trcsr		; Input capture / compare match flag D
ovf_trcsr			.btequ		7,trcsr		; Overflow flag
;
;-------------------------------------------------------
;   Timer RC I/O Control Register 0
;-------------------------------------------------------
trcior0				.equ		0124h
;
ioa0_trcior0		.btequ		0,trcior0	; TRCGRA control bit
ioa1_trcior0		.btequ		1,trcior0	; TRCGRA control bit
ioa2_trcior0		.btequ		2,trcior0	; TRCGRA mode select bit
ioa3_trcior0		.btequ		3,trcior0	; TRCGRA input capture input switch bit
iob0_trcior0		.btequ		4,trcior0	; TRCGRB control bit
iob1_trcior0		.btequ		5,trcior0	; TRCGRB control bit
iob2_trcior0		.btequ		6,trcior0	; TRCGRB mode select bit
;
;-------------------------------------------------------
;   Timer RC I/O Control Register 1
;-------------------------------------------------------
trcior1				.equ		0125h
;
ioc0_trcior1		.btequ		0,trcior1	; TRCGRC control bit
ioc1_trcior1		.btequ		1,trcior1	; TRCGRC control bit
ioc2_trcior1		.btequ		2,trcior1	; TRCGRC mode select bit
ioc3_trcior1		.btequ		3,trcior1	; TRCGRC register function select bit
iod0_trcior1		.btequ		4,trcior1	; TRCGRD control bit
iod1_trcior1		.btequ		5,trcior1	; TRCGRD control bit
iod2_trcior1		.btequ		6,trcior1	; TRCGRD mode select bit
iod3_trcior1		.btequ		7,trcior1	; TRCGRD register function select bit
;
;-------------------------------------------------------
;   Timer RC Counter
;-------------------------------------------------------
trc					.equ		0126h
;
;-------------------------------------------------------
;   Timer RC general register A
;-------------------------------------------------------
trcgra				.equ		0128h
;
;-------------------------------------------------------
;   Timer RC general register B
;-------------------------------------------------------
trcgrb				.equ		012Ah
;
;-------------------------------------------------------
;   Timer RC general register C
;-------------------------------------------------------
trcgrc				.equ		012Ch
;
;-------------------------------------------------------
;   Timer RC general register D
;-------------------------------------------------------
trcgrd				.equ		012Eh
;
;-------------------------------------------------------
;   Timer RC control register 2
;-------------------------------------------------------
trccr2				.equ		0130h
;
polb_trccr2			.btequ		0,trccr2	; PWM mode output level control bit B
polc_trccr2			.btequ		1,trccr2	; PWM mode output level control bit C
pold_trccr2			.btequ		2,trccr2	; PWM mode output level control bit D
csel_trccr2			.btequ		5,trccr2	; TRC count operation select bit
tceg0_trccr2		.btequ		6,trccr2	; TRCTRG input edge select bit
tceg1_trccr2		.btequ		7,trccr2	; TRCTRG input edge select bit
;
;-------------------------------------------------------
;   Timer RC Digital Filter Function Select Register
;-------------------------------------------------------
trcdf				.equ		0131h
;
dfa_trcdf			.btequ		0,trcdf		; TRCIOA pin digital filter function select bit
dfb_trcdf			.btequ		1,trcdf		; TRCIOB pin digital filter function select bit
dfc_trcdf			.btequ		2,trcdf		; TRCIOC pin digital filter function select bit
dfd_trcdf			.btequ		3,trcdf		; TRCIOD pin digital filter function select bit
dftrg_trcdf			.btequ		4,trcdf		; TRCTRG pin digital filter function select bit
dfck0_trcdf			.btequ		6,trcdf		; Clock select bits for digital filter function
dfck1_trcdf			.btequ		7,trcdf		; Clock select bits for digital filter function
;
;-------------------------------------------------------
;   Timer RC output master enable register
;-------------------------------------------------------
trcoer				.equ		0132h
;
ea_trcoer			.btequ		0,trcoer	; TRCIOA output disable bit
eb_trcoer			.btequ		1,trcoer	; TRCIOB output disable bit
ec_trcoer			.btequ		2,trcoer	; TRCIOC output disable bit
ed_trcoer			.btequ		3,trcoer	; TRCIOD output disable bit
pto_trcoer			.btequ		7,trcoer	; INT0 of pulse output forced cutoff signal input enabled bit
;
;-------------------------------------------------------
;   Timer RC trigger control register
;-------------------------------------------------------
trcadcr				.equ		0133h
;
adtrgae_trcadcr		.btequ		0,trcadcr	; A/D trigger A enable bit
adtrgbe_trcadcr		.btequ		1,trcadcr	; A/D trigger B enable bit
adtrgce_trcadcr		.btequ		2,trcadcr	; A/D trigger C enable bit
adtrgde_trcadcr		.btequ		3,trcadcr	; A/D trigger D enable bit
;
;-------------------------------------------------------
;   UART1 transmit/receive mode register
;-------------------------------------------------------
u1mr				.equ		0160h
;
smd0_u1mr			.btequ		0,u1mr		; Serial I/O mode select bit
smd1_u1mr			.btequ		1,u1mr		; Serial I/O mode select bit
smd2_u1mr			.btequ		2,u1mr		; Serial I/O mode select bit
ckdir_u1mr			.btequ		3,u1mr		; Internal/external clock select bit
stps_u1mr			.btequ		4,u1mr		; Stop bit length select bit
pry_u1mr			.btequ		5,u1mr		; Odd/even parity select bit
prye_u1mr			.btequ		6,u1mr		; Parity enable bit
;
;-------------------------------------------------------
;   UART1 bit rate register
;-------------------------------------------------------
u1brg				.equ		0161h
;
;-------------------------------------------------------
;   UART1 transmit buffer register
;-------------------------------------------------------
u1tb				.equ		0162h
;
u1tbl				.equ		u1tb		;       Low
u1tbh				.equ		u1tb+1		;       High
;
;-------------------------------------------------------
;   UART1 Transmit/Receive Control Register 0
;-------------------------------------------------------
u1c0				.equ		0164h
;
clk0_u1c0			.btequ		0,u1c0		; BRG count source select bit
clk1_u1c0			.btequ		1,u1c0		; BRG count source select bit
txept_u1c0			.btequ		3,u1c0		; Transmit register empty flag
nch_u1c0			.btequ		5,u1c0		; Data output select bit
ckpol_u1c0			.btequ		6,u1c0		; CLK polarity select bit
uform_u1c0			.btequ		7,u1c0		; Transfer format select bit
;
;-------------------------------------------------------
;   UART1 Transmit/Receive Control Register 1
;-------------------------------------------------------
u1c1				.equ		0165h
;
te_u1c1				.btequ		0,u1c1		; Transmit enable bit
ti_u1c1				.btequ		1,u1c1		; Transmit buffer empty flag
re_u1c1				.btequ		2,u1c1		; Receive enable bit
ri_u1c1				.btequ		3,u1c1		; Receive complete flag
u1irs_u1c1			.btequ		4,u1c1		; UART1 transmit interrupt source select bit
u1rrm_u1c1			.btequ		5,u1c1		; UART1 continuous receive mode enable bit
;
;-------------------------------------------------------
;   UART1 receive buffer register
;-------------------------------------------------------
u1rb				.equ		0166h
;
u1rbl				.equ		u1rb		;       Low
u1rbh				.equ		u1rb+1		;       High
oer_u1rb			.btequ		4,u1rbh		; Overrun error flag
fer_u1rb			.btequ		5,u1rbh		; Framing error flag
per_u1rb			.btequ		6,u1rbh		; Parity error flag
sum_u1rb			.btequ		7,u1rbh		; Error sum flag
;
;-------------------------------------------------------
;   Timer RA Pin Select Register
;-------------------------------------------------------
trasr				.equ		0180h
;
traiosel0			.btequ		0,trasr		; TRAIO pin select bit
traiosel1			.btequ		1,trasr		; TRAIO pin select bit
;
;-------------------------------------------------------
;   Timer RB/RC pin select register
;-------------------------------------------------------
trbrcsr				.equ		0181h
;
trbosel0			.btequ		0,trbrcsr	; TRBO pin select bit
trcclksel0			.btequ		4,trbrcsr	; TRCCLK pin select bit
trcclksel1			.btequ		5,trbrcsr	; TRCCLK pin select bit
;
;-------------------------------------------------------
;   Timer RC pin select register 0
;-------------------------------------------------------
trcpsr0				.equ		0182h
;
trcioasel0			.btequ		0,trcpsr0	; TRCIOA/TRCTRG pin select bit
trcioasel1			.btequ		1,trcpsr0	; TRCIOA/TRCTRG pin select bit
trcioasel2			.btequ		2,trcpsr0	; TRCIOA/TRCTRG pin select bit
trciobsel0			.btequ		4,trcpsr0	; TRCIOB pin select bit
trciobsel1			.btequ		5,trcpsr0	; TRCIOB pin select bit
trciobsel2			.btequ		6,trcpsr0	; TRCIOB pin select bit
;
;-------------------------------------------------------
;   Timer RC pin select register 1
;-------------------------------------------------------
trcpsr1				.equ		0183h
;
trciocsel0			.btequ		0,trcpsr1	; TRCIOC pin select bit
trciocsel1			.btequ		1,trcpsr1	; TRCIOC pin select bit
trciocsel2			.btequ		2,trcpsr1	; TRCIOC pin select bit
trciodsel0			.btequ		4,trcpsr1	; TRCIOD pin select bit
trciodsel1			.btequ		5,trcpsr1	; TRCIOD pin select bit
trciodsel2			.btequ		6,trcpsr1	; TRCIOD pin select bit
;
;-------------------------------------------------------
;   UART0 pin select register
;-------------------------------------------------------
u0sr				.equ		0188h
;
txd0sel0			.btequ		0,u0sr		; TXD0 pin select bit
rxd0sel0			.btequ		2,u0sr		; RXD0 pin select bit
clk0sel0			.btequ		4,u0sr		; CLK0 pin select bit
;
;-------------------------------------------------------
;   UART1 pin select register
;-------------------------------------------------------
u1sr				.equ		0189h
;
txd1sel0			.btequ		0,u1sr		; TXD1 pin select bit
rxd1sel0			.btequ		2,u1sr		; RXD1 pin select bit
clk1sel0			.btequ		4,u1sr		; CLK1 pin select bit
;
;-------------------------------------------------------
;   UART2 pin select register 0
;-------------------------------------------------------
u2sr0				.equ		018Ah
;
txd2sel0			.btequ		0,u2sr0		; TXD2/SDA2 pin select bit
txd2sel1			.btequ		1,u2sr0		; TXD2/SDA2 pin select bit
rxd2sel0			.btequ		4,u2sr0		; RXD2/SCL2 pin select bit
rxd2sel1			.btequ		5,u2sr0		; RXD2/SCL2 pin select bit
;
;-------------------------------------------------------
;   UART2 pin select register 1
;-------------------------------------------------------
u2sr1				.equ		018Bh
;
clk2sel0			.btequ		0,u2sr1		; CLK2 pin select bit
cts2sel0			.btequ		4,u2sr1		; CTS2/RTS2 pin select bit
;
;-------------------------------------------------------
;   SSU/IIC Pin Select Register
;-------------------------------------------------------
ssuiicsr			.equ		018Ch
;
iicsel				.btequ		0,ssuiicsr	; SSU/I2C bus switch bit
;
;-------------------------------------------------------
;   INT Interrupt Input Pin Select Register
;-------------------------------------------------------
intsr				.equ		018Eh
;
int1sel0			.btequ		1,intsr		; INT1 pin select bit
int1sel1			.btequ		2,intsr		; INT1 pin select bit
int1sel2			.btequ		3,intsr		; INT1 pin select bit
;
;-------------------------------------------------------
;   I/O Function Pin Select Register
;-------------------------------------------------------
pinsr				.equ		018Fh
;
ioinsel				.btequ		3,pinsr		; I/O port input function select bit
iictctwi			.btequ		4,pinsr		; I2C double transfer rate select bit
iictchalf			.btequ		5,pinsr		; I2C half transfer rate select bit
sdadly0				.btequ		6,pinsr		; SDA digital delay select bit
sdadly1				.btequ		7,pinsr		; SDA digital delay select bit
;
;-------------------------------------------------------
;   SS bit counter register
;-------------------------------------------------------
ssbr				.equ		0193h
;
bs0					.btequ		0,ssbr		; SSU data transfer length set bit
bs1					.btequ		1,ssbr		; SSU data transfer length set bit
bs2					.btequ		2,ssbr		; SSU data transfer length set bit
bs3					.btequ		3,ssbr		; SSU data transfer length set bit
;
;-------------------------------------------------------
;   SS transmit data register
;-------------------------------------------------------
sstdr				.equ		0194h
;
sstdrl				.equ		sstdr		;       Low
sstdrh				.equ		sstdr+1		;       High
;
;-------------------------------------------------------
;   IIC bus transmit data register
;-------------------------------------------------------
icdrt				.equ		0194h
;
;-------------------------------------------------------
;   SS receive data register
;-------------------------------------------------------
ssrdr				.equ		0196h
;
ssrdrl				.equ		ssrdr		;       Low
ssrdrh				.equ		ssrdr+1		;       High
;
;-------------------------------------------------------
;   IIC bus receive data register
;-------------------------------------------------------
icdrr				.equ		0196h
;
;-------------------------------------------------------
;   SS control register H
;-------------------------------------------------------
sscrh				.equ		0198h
;
cks0_sscrh			.btequ		0,sscrh		; Transfer clock select bit
cks1_sscrh			.btequ		1,sscrh		; Transfer clock select bit
cks2_sscrh			.btequ		2,sscrh		; Transfer clock select bit
mss_sscrh			.btequ		5,sscrh		; Master/Slave device select bit
rsstp_sscrh			.btequ		6,sscrh		; Receive single stop bit
;
;-------------------------------------------------------
;   IIC bus control register 1
;-------------------------------------------------------
iccr1				.equ		0198h
;
cks0_iccr1			.btequ		0,iccr1		; Transmit clock select bits 3 to 0
cks1_iccr1			.btequ		1,iccr1		; Transmit clock select bits 3 to 0
cks2_iccr1			.btequ		2,iccr1		; Transmit clock select bits 3 to 0
cks3_iccr1			.btequ		3,iccr1		; Transmit clock select bits 3 to 0
trs_iccr1			.btequ		4,iccr1		; Transfer/Receive select bit
mst_iccr1			.btequ		5,iccr1		; Master/Slave select bit
rcvd_iccr1			.btequ		6,iccr1		; Receive disable bit
ice_iccr1			.btequ		7,iccr1		; I2C bus interface enable bit
;
;-------------------------------------------------------
;   SS control register L
;-------------------------------------------------------
sscrl				.equ		0199h
;
sres_sscrl			.btequ		1,sscrl		; SSU control unit reset bit
solp_sscrl			.btequ		4,sscrl		; SOL write protect bit
sol_sscrl			.btequ		5,sscrl		; Serial data output value setting bit
;
;-------------------------------------------------------
;   IIC bus control register 2
;-------------------------------------------------------
iccr2				.equ		0199h
;
iicrst_iccr2		.btequ		1,iccr2		; I2C bus control block reset bit
sclo_iccr2			.btequ		3,iccr2		; SCL monitor flag
sdaop_iccr2			.btequ		4,iccr2		; SDAO write protect bit
sdao_iccr2			.btequ		5,iccr2		; SDA output value control bit
scp_iccr2			.btequ		6,iccr2		; Start/Stop condition generation disable bit
bbsy_iccr2			.btequ		7,iccr2		; Bus busy bit
;
;-------------------------------------------------------
;   SS Mode Register
;-------------------------------------------------------
ssmr				.equ		019Ah
;
bc0_ssmr			.btequ		0,ssmr		; Bits counter 3 to 0
bc1_ssmr			.btequ		1,ssmr		; Bits counter 3 to 0
bc2_ssmr			.btequ		2,ssmr		; Bits counter 3 to 0
bc3_ssmr			.btequ		3,ssmr		; Bits counter 3 to 0
cphs_ssmr			.btequ		5,ssmr		; SSCK clock phase select bit
cpos_ssmr			.btequ		6,ssmr		; SSCK clock polarity select bit
mls_ssmr			.btequ		7,ssmr		; MSB first/LSB first select bit
;
;-------------------------------------------------------
;   IIC bus mode register
;-------------------------------------------------------
icmr				.equ		019Ah
;
bc0_icmr			.btequ		0,icmr		; Bit counters 2 to 0
bc1_icmr			.btequ		1,icmr		; Bit counters 2 to 0
bc2_icmr			.btequ		2,icmr		; Bit counters 2 to 0
bcwp_icmr			.btequ		3,icmr		; BC write protect bit
wait_icmr			.btequ		6,icmr		; Wait insertion bit
mls_icmr			.btequ		7,icmr		; MSB-first/LSB-first select bit
;
;-------------------------------------------------------
;   SS Enable Register
;-------------------------------------------------------
sser				.equ		019bh
;
ceie_sser			.btequ		0,sser		; Conflict error interrupt enable bit
re_sser				.btequ		3,sser		; Receive enable bit
te_sser				.btequ		4,sser		; Transmit enable bit
rie_sser			.btequ		5,sser		; Receive interrupt enable bit
teie_sser			.btequ		6,sser		; Transmit end interrupt enable bit
tie_sser			.btequ		7,sser		; Transmit interrupt enable bit
;
;-------------------------------------------------------
;   IIC bus interrupt enable register
;-------------------------------------------------------
icier				.equ		019bh
;
ackbt_icier			.btequ		0,icier		; Transmit acknowledge select bit
ackbr_icier			.btequ		1,icier		; Receive acknowledge bit
acke_icier			.btequ		2,icier		; Acknowledge bit detection select bit
stie_icier			.btequ		3,icier		; Stop condition detection interrupt enable bit
nakie_icier			.btequ		4,icier		; NACK receive interrupt enable bit
rie_icier			.btequ		5,icier		; Receive interrupt enable bit
teie_icier			.btequ		6,icier		; Transmit end interrupt enable bit
tie_icier			.btequ		7,icier		; Transmit interrupt enable bit
;
;-------------------------------------------------------
;   SS Status Register
;-------------------------------------------------------
sssr				.equ		019ch
;
ce_sssr				.btequ		0,sssr		; Conflict error flag
orer_sssr			.btequ		2,sssr		; Overrun error flag
rdrf_sssr			.btequ		5,sssr		; Receive data register full flag
tend_sssr			.btequ		6,sssr		; Transmit end flag
tdre_sssr			.btequ		7,sssr		; Transmit data empty flag
;
;-------------------------------------------------------
;   IIC bus status register
;-------------------------------------------------------
icsr				.equ		019ch
;
adz_icsr			.btequ		0,icsr		; General call address recognition flag
aas_icsr			.btequ		1,icsr		; Slave address recognition flag
al_icsr				.btequ		2,icsr		; Arbitration lost flag/overrun error flag
stop_icsr			.btequ		3,icsr		; Stop condition detection flag
nackf_icsr			.btequ		4,icsr		; No acknowledge detection flag
rdrf_icsr			.btequ		5,icsr		; Receive data register full flag
tend_icsr			.btequ		6,icsr		; Transmit end flag
tdre_icsr			.btequ		7,icsr		; Transmit data empty flag
;
;-------------------------------------------------------
;   SS mode register 2
;-------------------------------------------------------
ssmr2				.equ		019dh
;
ssums_ssmr2			.btequ		0,ssmr2		; SSU mode select bit
csos_ssmr2			.btequ		1,ssmr2		; SCS pin open drain output select bit
soos_ssmr2			.btequ		2,ssmr2		; Serial data pin open output drain select bit
sckos_ssmr2			.btequ		3,ssmr2		; SSCK pin open drain output select bit
css0_ssmr2			.btequ		4,ssmr2		; SCS pin select bit
css1_ssmr2			.btequ		5,ssmr2		; SCS pin select bit
scks_ssmr2			.btequ		6,ssmr2		; SSCK pin select bit
bide_ssmr2			.btequ		7,ssmr2		; Bidirectional mode enable bit
;
;-------------------------------------------------------
;   Slave address register
;-------------------------------------------------------
sar					.equ		019dh
;
fs_sar				.btequ		0,sar		; Format select bit
sva0_sar			.btequ		1,sar		; Slave addresses 6 to 0
sva1_sar			.btequ		2,sar		; Slave addresses 6 to 0
sva2_sar			.btequ		3,sar		; Slave addresses 6 to 0
sva3_sar			.btequ		4,sar		; Slave addresses 6 to 0
sva4_sar			.btequ		5,sar		; Slave addresses 6 to 0
sva5_sar			.btequ		6,sar		; Slave addresses 6 to 0
sva6_sar			.btequ		7,sar		; Slave addresses 6 to 0
;
;-------------------------------------------------------
;   Flash memory status register
;-------------------------------------------------------
fst					.equ		01B2h
;
rdysti				.btequ		0,fst		; Flash ready status interrupt request flag
bsyaei				.btequ		1,fst		; Flash access error interrupt request flag
lbdata				.btequ		2,fst		; LBDATA monitor flag
fst4				.btequ		4,fst		; Program error flag
fst5				.btequ		5,fst		; Erase error/blank check error flag
fst6				.btequ		6,fst		; Erase-suspend status flag
fst7				.btequ		7,fst		; Ready/Busy status flag
;
;-------------------------------------------------------
;   Flash Memory Control Register 0
;-------------------------------------------------------
fmr0				.equ		01B4h
;
fmr01				.btequ		1,fmr0		; CPU rewrite mode select bit
fmr02				.btequ		2,fmr0		; EW1 mode select bit
fmstp				.btequ		3,fmr0		; Flash memory stop bit
cmdrst				.btequ		4,fmr0		; Erase/Write sequence reset bit
cmderie				.btequ		5,fmr0		; Erase/Write error interrupt enable bit
bsyaeie				.btequ		6,fmr0		; Flash access error interrupt enable bit
rdystie				.btequ		7,fmr0		; Flash ready status interrupt enable bit
;
;-------------------------------------------------------
;   Flash Memory Control Register 1
;-------------------------------------------------------
fmr1				.equ		01b5h
;
fmr13				.btequ		3,fmr1		; Lock bit disable select bit
fmr14				.btequ		4,fmr1		; Data flash block A rewrite disable bit
fmr15				.btequ		5,fmr1		; Data flash block B rewrite disable bit
fmr16				.btequ		6,fmr1		; Data flash block C rewrite disable bit
fmr17				.btequ		7,fmr1		; Data flash block D rewrite disable bit
;
;-------------------------------------------------------
;   Flash Memory Control Register 2
;-------------------------------------------------------
fmr2				.equ		01b6h
;
fmr20				.btequ		0,fmr2		; Erase-suspend enable bit
fmr21				.btequ		1,fmr2		; Erase-suspend request bit
fmr22				.btequ		2,fmr2		; Interrupt request suspend request enable bit
fmr27				.btequ		7,fmr2		; Low-consumption-current read mode enable bit
;
;-------------------------------------------------------
;   Address Match Interrupt Register 0
;-------------------------------------------------------
rmad0				.equ		01C0h
;
rmad0l				.equ		rmad0		;       Low
rmad0m				.equ		rmad0+1		;       Middle
rmad0h				.equ		rmad0+2		;       High
;
;-------------------------------------------------------
;   Address Match Interrupt Enable Register 0
;-------------------------------------------------------
aier0				.equ		01C3h
;
aier00				.btequ		0,aier0		; Address match interrupt 0 enable bit
;
;-------------------------------------------------------
;   Address Match Interrupt Register 1
;-------------------------------------------------------
rmad1				.equ		01C4h
;
rmad1l				.equ		rmad1		;       Low
rmad1m				.equ		rmad1+1		;       Middle
rmad1h				.equ		rmad1+2		;       High
;
;-------------------------------------------------------
;   Address Match Interrupt Enable Register 1
;-------------------------------------------------------
aier1				.equ		01C7h
;
aier10				.btequ		0,aier1		; Address match interrupt 1 enable bit
;
;-------------------------------------------------------
;   Pull-Up Control Register 0
;-------------------------------------------------------
pur0				.equ		01E0h
;
pu00				.btequ		0,pur0		; P0_0 to P0_3 pull-up
pu01				.btequ		1,pur0		; P0_4 to P0_7 pull-up
pu02				.btequ		2,pur0		; P1_0 to P1_3 pull-up
pu03				.btequ		3,pur0		; P1_4 to P1_7 pull-up
pu04				.btequ		4,pur0		; P2_0 to P2_2 pull-up
pu06				.btequ		6,pur0		; P3_1, P3_3 pull-up
pu07				.btequ		7,pur0		; P3_4, P3_5, P3_7 pull-up
;
;-------------------------------------------------------
;   Pull-Up Control Register 1
;-------------------------------------------------------
pur1				.equ		01E1h
;
pu11				.btequ		1,pur1		; P4_5 to P4_7 pull-up
;
;-------------------------------------------------------
;   Port P1 drive capacity control register
;-------------------------------------------------------
p1drr				.equ		01F0h
;
p1drr0				.btequ		0,p1drr		; P1_0 drive capacity
p1drr1				.btequ		1,p1drr		; P1_1 drive capacity
p1drr2				.btequ		2,p1drr		; P1_2 drive capacity
p1drr3				.btequ		3,p1drr		; P1_3 drive capacity
p1drr4				.btequ		4,p1drr		; P1_4 drive capacity
p1drr5				.btequ		5,p1drr		; P1_5 drive capacity
p1drr6				.btequ		6,p1drr		; P1_6 drive capacity
p1drr7				.btequ		7,p1drr		; P1_7 drive capacity
;
;-------------------------------------------------------
;   Port P2 drive capacity control register
;-------------------------------------------------------
p2drr				.equ		01F1h
;
p2drr0				.btequ		0,p2drr		; P2_0 drive capacity
p2drr1				.btequ		1,p2drr		; P2_1 drive capacity
p2drr2				.btequ		2,p2drr		; P2_2 drive capacity
;
;-------------------------------------------------------
;   Drive capacity control register 0
;-------------------------------------------------------
drr0				.equ		01F2h
;
drr00				.btequ		0,drr0		; P0_0 to P0_3 drive capacity
drr01				.btequ		1,drr0		; P0_4 to P0_7 drive capacity
drr06				.btequ		6,drr0		; P3_1, P3_3 drive capacity
drr07				.btequ		7,drr0		; P3_4, P3_5, P3_7 drive capacity
;
;-------------------------------------------------------
;   Drive capacity control register 1
;-------------------------------------------------------
drr1				.equ		01F3h
;
drr11				.btequ		1,drr1		; P4_5 to P4_7 drive capacity
;
;-------------------------------------------------------
;   Input threshold control register 0
;-------------------------------------------------------
vlt0				.equ		01F5h
;
vlt00				.btequ		0,vlt0		; P0 input level select bit
vlt01				.btequ		1,vlt0		; P0 input level select bit
vlt02				.btequ		2,vlt0		; P1 input level select bit
vlt03				.btequ		3,vlt0		; P1 input level select bit
vlt04				.btequ		4,vlt0		; P2_0 to P2_2 input level select bit
vlt05				.btequ		5,vlt0		; P2_0 to P2_2 input level select bit
vlt06				.btequ		6,vlt0		; P3_1, P3_3 to P3_5, P3_7 input level select bit
vlt07				.btequ		7,vlt0		; P3_1, P3_3 to P3_5, P3_7 input level select bit
;
;-------------------------------------------------------
;   Input threshold control register 1
;-------------------------------------------------------
vlt1				.equ		01F6h
;
vlt10				.btequ		0,vlt1		; P4_2, P4_5 to P4_7 input level select bit
vlt11				.btequ		1,vlt1		; P4_2, P4_5 to P4_7 input level select bit
;
;-------------------------------------------------------
;   Comparator B Control Register 0
;-------------------------------------------------------
intcmp				.equ		01F8h
;
int1cp0				.btequ		0,intcmp	; Comparator B1 operation enable bit
int1cout			.btequ		3,intcmp	; Comparator B1 monitor flag
int3cp0				.btequ		4,intcmp	; Comparator B3 operation enable bit
int3cout			.btequ		7,intcmp	; Comparator B3 monitor flag
;
;-------------------------------------------------------
;   External Input Enable Register 0
;-------------------------------------------------------
inten				.equ		01FAh
;
int0en				.btequ		0,inten		; INT0 input enable bit
int0pl				.btequ		1,inten		; INT0 input polarity select bit
int1en				.btequ		2,inten		; INT1 input enable bit
int1pl				.btequ		3,inten		; INT1 input polarity select bit
int3en				.btequ		6,inten		; INT3 input enable bit
int3pl				.btequ		7,inten		; INT3 input polarity select bit
;
;-------------------------------------------------------
;   INT Input Filter Select Register 0
;-------------------------------------------------------
intf				.equ		01FCh
;
int0f0				.btequ		0,intf		; INT0 input filter select bit
int0f1				.btequ		1,intf		; INT0 input filter select bit
int1f0				.btequ		2,intf		; INT1 input filter select bit
int1f1				.btequ		3,intf		; INT1 input filter select bit
int3f0				.btequ		6,intf		; INT3 input filter select bit
int3f1				.btequ		7,intf		; INT3 input filter select bit
;
;-------------------------------------------------------
;   Key Input Enable Register 0
;-------------------------------------------------------
kien				.equ		01FEh
;
ki0en				.btequ		0,kien		; KI0 input enable bit
ki0pl				.btequ		1,kien		; KI0 input polarity select bit
ki1en				.btequ		2,kien		; KI1 input enable bit
ki1pl				.btequ		3,kien		; KI1 input polarity select bit
ki2en				.btequ		4,kien		; KI2 input enable bit
ki2pl				.btequ		5,kien		; KI2 input polarity select bit
ki3en				.btequ		6,kien		; KI3 input enable bit
ki3pl				.btequ		7,kien		; KI3 input polarity select bit
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 0 (INT0)
;-------------------------------------------------------
dtcvct0			.equ		2C00H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 1 (INT1)
;-------------------------------------------------------
dtcvct1			.equ		2C01H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 2
;-------------------------------------------------------
dtcvct2			.equ		2C02H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 3 (INT3)
;-------------------------------------------------------
dtcvct3			.equ		2C03H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 4
;-------------------------------------------------------
dtcvct4			.equ		2C04H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 5
;-------------------------------------------------------
dtcvct5			.equ		2C05H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 6
;-------------------------------------------------------
dtcvct6			.equ		2C06H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 7
;-------------------------------------------------------
dtcvct7			.equ		2C07H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 8 (Key Input)
;-------------------------------------------------------
dtcvct8			.equ		2C08H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 9 (A/D)
;-------------------------------------------------------
dtcvct9			.equ		2C09H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 10 (Uart0 Receive)
;-------------------------------------------------------
dtcvct10		.equ		2C0AH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 11 (Uart0 Transfer)
;-------------------------------------------------------
dtcvct11		.equ		2C0BH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 12 (Uart1 Receive)
;-------------------------------------------------------
dtcvct12		.equ		2C0CH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 13 (Uart1 Transfer)
;-------------------------------------------------------
dtcvct13		.equ		2C0DH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 14 (Uart2 Receive)*//* 3x */
;-------------------------------------------------------
dtcvct14		.equ		2C0EH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 15 (Uart2 Transfer)
;-------------------------------------------------------
dtcvct15		.equ		2C0FH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 16 (SSU/I2C Receive data register full)
;-------------------------------------------------------
dtcvct16		.equ		2C10H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 17 (SSU/I2C Transmit data empty)
;-------------------------------------------------------
dtcvct17		.equ		2C11H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 18 (Voltage monitor circuit 2)
;-------------------------------------------------------
dtcvct18		.equ		2C12H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 19 (Voltage monitor circuit 1)
;-------------------------------------------------------
dtcvct19		.equ		2C13H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 20
;-------------------------------------------------------
dtcvct20		.equ		2C14H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 21
;-------------------------------------------------------
dtcvct21		.equ		2C15H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 22 (TRC Input capture / compare match A)
;-------------------------------------------------------
dtcvct22		.equ		2C16H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 23 (TRC Input capture / compare match B)
;-------------------------------------------------------
dtcvct23		.equ		2C17H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 24 (TRC Input capture / compare match C)
;-------------------------------------------------------
dtcvct24		.equ		2C18H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 25 (TRC Input capture / compare match D)
;-------------------------------------------------------
dtcvct25		.equ		2C19H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 26
;-------------------------------------------------------
dtcvct26		.equ		2C1AH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 27
;-------------------------------------------------------
dtcvct27		.equ		2C1BH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 28
;-------------------------------------------------------
dtcvct28		.equ		2C1CH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 29
;-------------------------------------------------------
dtcvct29		.equ		2C1DH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 30
;-------------------------------------------------------
dtcvct30		.equ		2C1EH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 31
;-------------------------------------------------------
dtcvct31		.equ		2C1FH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 32
;-------------------------------------------------------
dtcvct32		.equ		2C20H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 33
;-------------------------------------------------------
dtcvct33		.equ		2C21H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 34
;-------------------------------------------------------
dtcvct34		.equ		2C22H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 35
;-------------------------------------------------------
dtcvct35		.equ		2C23H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 36
;-------------------------------------------------------
dtcvct36		.equ		2C24H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 37
;-------------------------------------------------------
dtcvct37		.equ		2C25H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 38
;-------------------------------------------------------
dtcvct38		.equ		2C26H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 39
;-------------------------------------------------------
dtcvct39		.equ		2C27H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 40
;-------------------------------------------------------
dtcvct40		.equ		2C28H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 41
;-------------------------------------------------------
dtcvct41		.equ		2C29H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 42 (TRE)
;-------------------------------------------------------
dtcvct42		.equ		2C2AH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 43
;-------------------------------------------------------
dtcvct43		.equ		2C2BH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 44
;-------------------------------------------------------
dtcvct44		.equ		2C2CH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 45
;-------------------------------------------------------
dtcvct45		.equ		2C2DH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 46
;-------------------------------------------------------
dtcvct46		.equ		2C2EH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 47
;-------------------------------------------------------
dtcvct47		.equ		2C2FH
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 48
;-------------------------------------------------------
dtcvct48		.equ		2C30H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 49 (TRA)
;-------------------------------------------------------
dtcvct49		.equ		2C31H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 50
;-------------------------------------------------------
dtcvct50		.equ		2C32H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 51 (TRB)
;-------------------------------------------------------
dtcvct51		.equ		2C33H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 52 (Flash memory ready)
;-------------------------------------------------------
dtcvct52		.equ		2C34H
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 53
;-------------------------------------------------------
dtcvct53			.equ		2C35h
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 54
;-------------------------------------------------------
dtcvct54			.equ		2C36h
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 55
;-------------------------------------------------------
dtcvct55			.equ		2C37h
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 56
;-------------------------------------------------------
dtcvct56			.equ		2C38h
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 57
;-------------------------------------------------------
dtcvct57			.equ		2C39h
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 58
;-------------------------------------------------------
dtcvct58			.equ		2C3Ah
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 59
;-------------------------------------------------------
dtcvct59			.equ		2C3Bh
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 60
;-------------------------------------------------------
dtcvct60			.equ		2C3Ch
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 61
;-------------------------------------------------------
dtcvct61			.equ		2C3Dh
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 62
;-------------------------------------------------------
dtcvct62			.equ		2C3Eh
;
;-------------------------------------------------------
;   DTC Transfer Vector Area 63
;-------------------------------------------------------
dtcvct63			.equ		2C3Fh
;
;-------------------------------------------------------
; DTC Control register 0
;-------------------------------------------------------
dtccr0			.equ		2C40H
;
mode_dtccr0		.btequ		0,dtccr0		; Transfer mode select bit
rptsel_dtccr0	.btequ		1,dtccr0		; Repeat area select bit
samod_dtccr0	.btequ		2,dtccr0		; Source address control bit
damod_dtccr0	.btequ		3,dtccr0		; Destination address control bit
chne_dtccr0		.btequ		4,dtccr0		; Chain transfer enable bit
rptint_dtccr0	.btequ		5,dtccr0		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 0
;-------------------------------------------------------
dtbls0			.equ		2C41H

;-------------------------------------------------------
; DTC Transfer count register 0
;-------------------------------------------------------
dtcct0			.equ		2C42H
;
;-------------------------------------------------------
; DTC Transfer count reload register 0
;-------------------------------------------------------
dtrld0			.equ		2C43H
;
;-------------------------------------------------------
; DTC Source address register 0
;-------------------------------------------------------
dtsar0			.equ		2C44H
;
;-------------------------------------------------------
; DTC Destination register 0
;-------------------------------------------------------
dtdar0			.equ		2C46H
;
;-------------------------------------------------------
; DTC Control register 1
;-------------------------------------------------------
dtccr1			.equ		2C48H
;
mode_dtccr1		.btequ		0,dtccr1		; Transfer mode select bit
rptsel_dtccr1	.btequ		1,dtccr1		; Repeat area select bit
samod_dtccr1	.btequ		2,dtccr1		; Source address control bit
damod_dtccr1	.btequ		3,dtccr1		; Destination address control bit
chne_dtccr1		.btequ		4,dtccr1		; Chain transfer enable bit
rptint_dtccr1	.btequ		5,dtccr1		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 1
;-------------------------------------------------------
dtbls1			.equ		2C49H
;
;-------------------------------------------------------
; DTC Transfer count register 1
;-------------------------------------------------------
dtcct1			.equ		2C4AH
;
;-------------------------------------------------------
; DTC Transfer count reload register 1
;-------------------------------------------------------
dtrld1			.equ		2C4BH
;
;-------------------------------------------------------
; DTC Source address register 1
;-------------------------------------------------------
dtsar1			.equ		2C4CH
;
;-------------------------------------------------------
; DTC Destination register 1
;-------------------------------------------------------
dtdar1			.equ		2C4EH
;
;-------------------------------------------------------
; DTC Control register 2
;-------------------------------------------------------
dtccr2			.equ		2C50H
;
mode_dtccr2		.btequ		0,dtccr2		; Transfer mode select bit
rptsel_dtccr2	.btequ		1,dtccr2		; Repeat area select bit
samod_dtccr2	.btequ		2,dtccr2		; Source address control bit
damod_dtccr2	.btequ		3,dtccr2		; Destination address control bit
chne_dtccr2		.btequ		4,dtccr2		; Chain transfer enable bit
rptint_dtccr2	.btequ		5,dtccr2		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 2
;-------------------------------------------------------
dtbls2			.equ		2C51H
;
;-------------------------------------------------------
; DTC Transfer count register 2
;-------------------------------------------------------
dtcct2			.equ		2C52H
;
;-------------------------------------------------------
; DTC Transfer count reload register 2
;-------------------------------------------------------
dtrld2			.equ		2C53H
;
;-------------------------------------------------------
; DTC Source address register 2
;-------------------------------------------------------
dtsar2			.equ		2C54H
;
;-------------------------------------------------------
; DTC Destination register 2
;-------------------------------------------------------
dtdar2			.equ		2C56H
;
;-------------------------------------------------------
; DTC Control register 3
;-------------------------------------------------------
dtccr3			.equ		2C58H
;
mode_dtccr3		.btequ		0,dtccr3		; Transfer mode select bit
rptsel_dtccr3	.btequ		1,dtccr3		; Repeat area select bit
samod_dtccr3	.btequ		2,dtccr3		; Source address control bit
damod_dtccr3	.btequ		3,dtccr3		; Destination address control bit
chne_dtccr3		.btequ		4,dtccr3		; Chain transfer enable bit
rptint_dtccr3	.btequ		5,dtccr3		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 3
;-------------------------------------------------------
dtbls3			.equ		2C59H
;
;-------------------------------------------------------
; DTC Transfer count register 3
;-------------------------------------------------------
dtcct3			.equ		2C5AH
;
;-------------------------------------------------------
; DTC Transfer count reload register 3
;-------------------------------------------------------
dtrld3			.equ		2C5BH
;
;-------------------------------------------------------
; DTC Source address register 3
;-------------------------------------------------------
dtsar3			.equ		2C5CH
;
;-------------------------------------------------------
; DTC Destination register 3
;-------------------------------------------------------
dtdar3			.equ		2C5EH
;
;-------------------------------------------------------
; DTC Control register 4
;-------------------------------------------------------
dtccr4			.equ		2C60H
;
mode_dtccr4		.btequ		0,dtccr4		; Transfer mode select bit
rptsel_dtccr4	.btequ		1,dtccr4		; Repeat area select bit
samod_dtccr4	.btequ		2,dtccr4		; Source address control bit
damod_dtccr4	.btequ		3,dtccr4		; Destination address control bit
chne_dtccr4		.btequ		4,dtccr4		; Chain transfer enable bit
rptint_dtccr4	.btequ		5,dtccr4		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 4
;-------------------------------------------------------
dtbls4			.equ		2C61H
;
;-------------------------------------------------------
; DTC Transfer count register 4
;-------------------------------------------------------
dtcct4			.equ		2C62H
;
;-------------------------------------------------------
; DTC Transfer count reload register 4
;-------------------------------------------------------
dtrld4			.equ		2C63H
;
;-------------------------------------------------------
; DTC Source address register 4
;-------------------------------------------------------
dtsar4			.equ		2C64H
;
;-------------------------------------------------------
; DTC Destination register 4
;-------------------------------------------------------
dtdar4			.equ		2C66H
;
;-------------------------------------------------------
; DTC Control register 5
;-------------------------------------------------------
dtccr5			.equ		2C68H
;
mode_dtccr5		.btequ		0,dtccr5		; Transfer mode select bit
rptsel_dtccr5	.btequ		1,dtccr5		; Repeat area select bit
samod_dtccr5	.btequ		2,dtccr5		; Source address control bit
damod_dtccr5	.btequ		3,dtccr5		; Destination address control bit
chne_dtccr5		.btequ		4,dtccr5		; Chain transfer enable bit
rptint_dtccr5	.btequ		5,dtccr5		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 5
;-------------------------------------------------------
dtbls5			.equ		2C69H
;
;-------------------------------------------------------
; DTC Transfer count register 5
;-------------------------------------------------------
dtcct5			.equ		2C6AH
;
;-------------------------------------------------------
; DTC Transfer count reload register 5
;-------------------------------------------------------
dtrld5			.equ		2C6BH
;
;-------------------------------------------------------
; DTC Source address register 5
;-------------------------------------------------------
dtsar5			.equ		2C6CH
;
;-------------------------------------------------------
; DTC Destination register 5
;-------------------------------------------------------
dtdar5			.equ		2C6EH
;
;-------------------------------------------------------
; DTC Control register 6
;-------------------------------------------------------
dtccr6			.equ		2C70H
;
mode_dtccr6		.btequ		0,dtccr6		; Transfer mode select bit
rptsel_dtccr6	.btequ		1,dtccr6		; Repeat area select bit
samod_dtccr6	.btequ		2,dtccr6		; Source address control bit
damod_dtccr6	.btequ		3,dtccr6		; Destination address control bit
chne_dtccr6		.btequ		4,dtccr6		; Chain transfer enable bit
rptint_dtccr6	.btequ		5,dtccr6		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 6
;-------------------------------------------------------
dtbls6			.equ		2C71H
;
;-------------------------------------------------------
; DTC Transfer count register 6
;-------------------------------------------------------
dtcct6			.equ		2C72H
;
;-------------------------------------------------------
; DTC Transfer count reload register 6
;-------------------------------------------------------
dtrld6			.equ		2C73H
;
;-------------------------------------------------------
; DTC Source address register 6
;-------------------------------------------------------
dtsar6			.equ		2C74H
;
;-------------------------------------------------------
; DTC Destination register 6
;-------------------------------------------------------
dtdar6			.equ		2C76H
;
;-------------------------------------------------------
; DTC Control register 7
;-------------------------------------------------------
dtccr7			.equ		2C78H
;
mode_dtccr7		.btequ		0,dtccr7		; Transfer mode select bit
rptsel_dtccr7	.btequ		1,dtccr7		; Repeat area select bit
samod_dtccr7	.btequ		2,dtccr7		; Source address control bit
damod_dtccr7	.btequ		3,dtccr7		; Destination address control bit
chne_dtccr7		.btequ		4,dtccr7		; Chain transfer enable bit
rptint_dtccr7	.btequ		5,dtccr7		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 7
;-------------------------------------------------------
dtbls7			.equ		2C79H
;
;-------------------------------------------------------
; DTC Transfer count register 7
;-------------------------------------------------------
dtcct7			.equ		2C7AH
;
;-------------------------------------------------------
; DTC Transfer count reload register 7
;-------------------------------------------------------
dtrld7			.equ		2C7BH
;
;-------------------------------------------------------
; DTC Source address register 7
;-------------------------------------------------------
dtsar7			.equ		2C7CH
;
;-------------------------------------------------------
; DTC Destination register 7
;-------------------------------------------------------
dtdar7			.equ		2C7EH
;
;-------------------------------------------------------
; DTC Control register 8
;-------------------------------------------------------
dtccr8			.equ		2C80H
;
mode_dtccr8		.btequ		0,dtccr8		; Transfer mode select bit
rptsel_dtccr8	.btequ		1,dtccr8		; Repeat area select bit
samod_dtccr8	.btequ		2,dtccr8		; Source address control bit
damod_dtccr8	.btequ		3,dtccr8		; Destination address control bit
chne_dtccr8		.btequ		4,dtccr8		; Chain transfer enable bit
rptint_dtccr8	.btequ		5,dtccr8		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 8
;-------------------------------------------------------
dtbls8			.equ		2C81H
;
;-------------------------------------------------------
; DTC Transfer count register 8
;-------------------------------------------------------
dtcct8			.equ		2C82H
;
;-------------------------------------------------------
; DTC Transfer count reload register 8
;-------------------------------------------------------
dtrld8			.equ		2C83H
;
;-------------------------------------------------------
; DTC Source address register 8
;-------------------------------------------------------
dtsar8			.equ		2C84H
;
;-------------------------------------------------------
; DTC Destination register 8
;-------------------------------------------------------
dtdar8			.equ		2C86H
;
;-------------------------------------------------------
; DTC Control register 9
;-------------------------------------------------------
dtccr9			.equ		2C88H
;
mode_dtccr9		.btequ		0,dtccr9		; Transfer mode select bit
rptsel_dtccr9	.btequ		1,dtccr9		; Repeat area select bit
samod_dtccr9	.btequ		2,dtccr9		; Source address control bit
damod_dtccr9	.btequ		3,dtccr9		; Destination address control bit
chne_dtccr9		.btequ		4,dtccr9		; Chain transfer enable bit
rptint_dtccr9	.btequ		5,dtccr9		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 9
;-------------------------------------------------------
dtbls9			.equ		2C89H
;
;-------------------------------------------------------
; DTC Transfer count register 9
;-------------------------------------------------------
dtcct9			.equ		2C8AH
;
;-------------------------------------------------------
; DTC Transfer count reload register 9
;-------------------------------------------------------
dtrld9			.equ		2C8BH
;
;-------------------------------------------------------
; DTC Source address register 9
;-------------------------------------------------------
dtsar9			.equ		2C8CH
;
;-------------------------------------------------------
; DTC Destination register 9
;-------------------------------------------------------
dtdar9			.equ		2C8EH
;
;-------------------------------------------------------
; DTC Control register 10
;-------------------------------------------------------
dtccr10			.equ		2C90H
;
mode_dtccr10	.btequ		0,dtccr10		; Transfer mode select bit
rptsel_dtccr10	.btequ		1,dtccr10		; Repeat area select bit
samod_dtccr10	.btequ		2,dtccr10		; Source address control bit
damod_dtccr10	.btequ		3,dtccr10		; Destination address control bit
chne_dtccr10	.btequ		4,dtccr10		; Chain transfer enable bit
rptint_dtccr10	.btequ		5,dtccr10		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 10
;-------------------------------------------------------
dtbls10			.equ		2C91H
;
;-------------------------------------------------------
; DTC Transfer count register 10
;-------------------------------------------------------
dtcct10			.equ		2C92H
;
;-------------------------------------------------------
; DTC Transfer count reload register 10
;-------------------------------------------------------
dtrld10			.equ		2C93H
;
;-------------------------------------------------------
; DTC Source address register 10
;-------------------------------------------------------
dtsar10			.equ		2C94H
;
;-------------------------------------------------------
; DTC Destination register 10
;-------------------------------------------------------
dtdar10			.equ		2C96H
;
;-------------------------------------------------------
; DTC Control register 11
;-------------------------------------------------------
dtccr11			.equ		2C98H
;
mode_dtccr11	.btequ		0,dtccr11		; Transfer mode select bit
rptsel_dtccr11	.btequ		1,dtccr11		; Repeat area select bit
samod_dtccr11	.btequ		2,dtccr11		; Source address control bit
damod_dtccr11	.btequ		3,dtccr11		; Destination address control bit
chne_dtccr11	.btequ		4,dtccr11		; Chain transfer enable bit
rptint_dtccr11	.btequ		5,dtccr11		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 11
;-------------------------------------------------------
dtbls11			.equ		2C99H
;
;-------------------------------------------------------
; DTC Transfer count register 11
;-------------------------------------------------------
dtcct11			.equ		2C9AH
;
;-------------------------------------------------------
; DTC Transfer count reload register 11
;-------------------------------------------------------
dtrld11			.equ		2C9BH
;
;-------------------------------------------------------
; DTC Source address register 11
;-------------------------------------------------------
dtsar11			.equ		2C9CH
;
;-------------------------------------------------------
; DTC Destination register 11
;-------------------------------------------------------
dtdar11			.equ		2C9EH
;
;-------------------------------------------------------
; DTC Control register 12
;-------------------------------------------------------
dtccr12			.equ		2CA0H
;
mode_dtccr12	.btequ		0,dtccr12		; Transfer mode select bit
rptsel_dtccr12	.btequ		1,dtccr12		; Repeat area select bit
samod_dtccr12	.btequ		2,dtccr12		; Source address control bit
damod_dtccr12	.btequ		3,dtccr12		; Destination address control bit
chne_dtccr12	.btequ		4,dtccr12		; Chain transfer enable bit
rptint_dtccr12	.btequ		5,dtccr12		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 12
;-------------------------------------------------------
dtbls12			.equ		2CA1H
;
;-------------------------------------------------------
; DTC Transfer count register 12
;-------------------------------------------------------
dtcct12			.equ		2CA2H
;
;-------------------------------------------------------
; DTC Transfer count reload register 12
;-------------------------------------------------------
dtrld12			.equ		2CA3H
;
;-------------------------------------------------------
; DTC Source address register 12
;-------------------------------------------------------
dtsar12			.equ		2CA4H
;
;-------------------------------------------------------
; DTC Destination register 12
;-------------------------------------------------------
dtdar12			.equ		2CA6H
;
;-------------------------------------------------------
; DTC Control register 13
;-------------------------------------------------------
dtccr13			.equ		2CA8H
;
mode_dtccr13	.btequ		0,dtccr13		; Transfer mode select bit
rptsel_dtccr13	.btequ		1,dtccr13		; Repeat area select bit
samod_dtccr13	.btequ		2,dtccr13		; Source address control bit
damod_dtccr13	.btequ		3,dtccr13		; Destination address control bit
chne_dtccr13	.btequ		4,dtccr13		; Chain transfer enable bit
rptint_dtccr13	.btequ		5,dtccr13		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 13
;-------------------------------------------------------
dtbls13			.equ		2CA9H
;
;-------------------------------------------------------
; DTC Transfer count register 13
;-------------------------------------------------------
dtcct13			.equ		2CAAH
;
;-------------------------------------------------------
; DTC Transfer count reload register 13
;-------------------------------------------------------
dtrld13			.equ		2CABH
;
;-------------------------------------------------------
; DTC Source address register 13
;-------------------------------------------------------
dtsar13			.equ		2CACH
;
;-------------------------------------------------------
; DTC Destination register 13
;-------------------------------------------------------
dtdar13			.equ		2CAEH
;
;-------------------------------------------------------
; DTC Control register 14
;-------------------------------------------------------
dtccr14			.equ		2CB0H
;
mode_dtccr14	.btequ		0,dtccr14		; Transfer mode select bit
rptsel_dtccr14	.btequ		1,dtccr14		; Repeat area select bit
samod_dtccr14	.btequ		2,dtccr14		; Source address control bit
damod_dtccr14	.btequ		3,dtccr14		; Destination address control bit
chne_dtccr14	.btequ		4,dtccr14		; Chain transfer enable bit
rptint_dtccr14	.btequ		5,dtccr14		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 14
;-------------------------------------------------------
dtbls14			.equ		2CB1H
;
;-------------------------------------------------------
; DTC Transfer count register 14
;-------------------------------------------------------
dtcct14			.equ		2CB2H
;
;-------------------------------------------------------
; DTC Transfer count reload register 14
;-------------------------------------------------------
dtrld14			.equ		2CB3H
;
;-------------------------------------------------------
; DTC Source address register 14
;-------------------------------------------------------
dtsar14			.equ		2CB4H
;
;-------------------------------------------------------
; DTC Destination register 14
;-------------------------------------------------------
dtdar14			.equ		2CB6H
;
;-------------------------------------------------------
; DTC Control register 15
;-------------------------------------------------------
dtccr15			.equ		2CB8H
;
mode_dtccr15	.btequ		0,dtccr15		; Transfer mode select bit
rptsel_dtccr15	.btequ		1,dtccr15		; Repeat area select bit
samod_dtccr15	.btequ		2,dtccr15		; Source address control bit
damod_dtccr15	.btequ		3,dtccr15		; Destination address control bit
chne_dtccr15	.btequ		4,dtccr15		; Chain transfer enable bit
rptint_dtccr15	.btequ		5,dtccr15		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 15
;-------------------------------------------------------
dtbls15			.equ		2CB9H
;
;-------------------------------------------------------
; DTC Transfer count register 15
;-------------------------------------------------------
dtcct15			.equ		2CBAH
;
;-------------------------------------------------------
; DTC Transfer count reload register 15
;-------------------------------------------------------
dtrld15			.equ		2CBBH
;
;-------------------------------------------------------
; DTC Source address register 15
;-------------------------------------------------------
dtsar15			.equ		2CBCH
;
;-------------------------------------------------------
; DTC Destination register 15
;-------------------------------------------------------
dtdar15			.equ		2CBEH
;
;-------------------------------------------------------
; DTC Control register 16
;-------------------------------------------------------
dtccr16			.equ		2CC0H
;
mode_dtccr16	.btequ		0,dtccr16		; Transfer mode select bit
rptsel_dtccr16	.btequ		1,dtccr16		; Repeat area select bit
samod_dtccr16	.btequ		2,dtccr16		; Source address control bit
damod_dtccr16	.btequ		3,dtccr16		; Destination address control bit
chne_dtccr16	.btequ		4,dtccr16		; Chain transfer enable bit
rptint_dtccr16	.btequ		5,dtccr16		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 16
;-------------------------------------------------------
dtbls16			.equ		2CC1H
;
;-------------------------------------------------------
; DTC Transfer count register 16
;-------------------------------------------------------
dtcct16			.equ		2CC2H
;
;-------------------------------------------------------
; DTC Transfer count reload register 16
;-------------------------------------------------------
dtrld16			.equ		2CC3H
;
;-------------------------------------------------------
; DTC Source address register 16
;-------------------------------------------------------
dtsar16			.equ		2CC4H
;
;-------------------------------------------------------
; DTC Destination register 16
;-------------------------------------------------------
dtdar16			.equ		2CC6H
;
;-------------------------------------------------------
; DTC Control register 17
;-------------------------------------------------------
dtccr17			.equ		2CC8H
;
mode_dtccr17	.btequ		0,dtccr17		; Transfer mode select bit
rptsel_dtccr17	.btequ		1,dtccr17		; Repeat area select bit
samod_dtccr17	.btequ		2,dtccr17		; Source address control bit
damod_dtccr17	.btequ		3,dtccr17		; Destination address control bit
chne_dtccr17	.btequ		4,dtccr17		; Chain transfer enable bit
rptint_dtccr17	.btequ		5,dtccr17		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 17
;-------------------------------------------------------
dtbls17			.equ		2CC9H
;
;-------------------------------------------------------
; DTC Transfer count register 17
;-------------------------------------------------------
dtcct17			.equ		2CCAH
;
;-------------------------------------------------------
; DTC Transfer count reload register 17
;-------------------------------------------------------
dtrld17			.equ		2CCBH
;
;-------------------------------------------------------
; DTC Source address register 17
;-------------------------------------------------------
dtsar17			.equ		2CCCH
;
;-------------------------------------------------------
; DTC Destination register 17
;-------------------------------------------------------
dtdar17			.equ		2CCEH
;
;-------------------------------------------------------
; DTC Control register 18
;-------------------------------------------------------
dtccr18			.equ		2CD0H
;
mode_dtccr18	.btequ		0,dtccr18		; Transfer mode select bit
rptsel_dtccr18	.btequ		1,dtccr18		; Repeat area select bit
samod_dtccr18	.btequ		2,dtccr18		; Source address control bit
damod_dtccr18	.btequ		3,dtccr18		; Destination address control bit
chne_dtccr18	.btequ		4,dtccr18		; Chain transfer enable bit
rptint_dtccr18	.btequ		5,dtccr18		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 18
;-------------------------------------------------------
dtbls18			.equ		2CD1H
;
;-------------------------------------------------------
; DTC Transfer count register 18
;-------------------------------------------------------
dtcct18			.equ		2CD2H
;
;-------------------------------------------------------
; DTC Transfer count reload register 18
;-------------------------------------------------------
dtrld18			.equ		2CD3H
;
;-------------------------------------------------------
; DTC Source address register 18
;-------------------------------------------------------
dtsar18			.equ		2CD4H
;
;-------------------------------------------------------
; DTC Destination register 18
;-------------------------------------------------------
dtdar18			.equ		2CD6H
;
;-------------------------------------------------------
; DTC Control register 19
;-------------------------------------------------------
dtccr19			.equ		2CD8H
;
mode_dtccr19	.btequ		0,dtccr19		; Transfer mode select bit
rptsel_dtccr19	.btequ		1,dtccr19		; Repeat area select bit
samod_dtccr19	.btequ		2,dtccr19		; Source address control bit
damod_dtccr19	.btequ		3,dtccr19		; Destination address control bit
chne_dtccr19	.btequ		4,dtccr19		; Chain transfer enable bit
rptint_dtccr19	.btequ		5,dtccr19		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 19
;-------------------------------------------------------
dtbls19			.equ		2CD9H
;
;-------------------------------------------------------
; DTC Transfer count register 19
;-------------------------------------------------------
dtcct19			.equ		2CDAH
;
;-------------------------------------------------------
; DTC Transfer count reload register 19
;-------------------------------------------------------
dtrld19			.equ		2CDBH
;
;-------------------------------------------------------
; DTC Source address register 19
;-------------------------------------------------------
dtsar19			.equ		2CDCH
;
;-------------------------------------------------------
; DTC Destination register 19
;-------------------------------------------------------
dtdar19			.equ		2CDEH
;
;-------------------------------------------------------
; DTC Control register 20
;-------------------------------------------------------
dtccr20			.equ		2CE0H
;
mode_dtccr20	.btequ		0,dtccr20		; Transfer mode select bit
rptsel_dtccr20	.btequ		1,dtccr20		; Repeat area select bit
samod_dtccr20	.btequ		2,dtccr20		; Source address control bit
damod_dtccr20	.btequ		3,dtccr20		; Destination address control bit
chne_dtccr20	.btequ		4,dtccr20		; Chain transfer enable bit
rptint_dtccr20	.btequ		5,dtccr20		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 20
;-------------------------------------------------------
dtbls20			.equ		2CE1H
;
;-------------------------------------------------------
; DTC Transfer count register 20
;-------------------------------------------------------
dtcct20			.equ		2CE2H
;
;-------------------------------------------------------
; DTC Transfer count reload register 20
;-------------------------------------------------------
dtrld20			.equ		2CE3H
;
;-------------------------------------------------------
; DTC Source address register 20
;-------------------------------------------------------
dtsar20			.equ		2CE4H
;
;-------------------------------------------------------
; DTC Destination register 20
;-------------------------------------------------------
dtdar20			.equ		2CE6H
;
;-------------------------------------------------------
; DTC Control register 21
;-------------------------------------------------------
dtccr21			.equ		2CE8H
;
mode_dtccr21	.btequ		0,dtccr21		; Transfer mode select bit
rptsel_dtccr21	.btequ		1,dtccr21		; Repeat area select bit
samod_dtccr21	.btequ		2,dtccr21		; Source address control bit
damod_dtccr21	.btequ		3,dtccr21		; Destination address control bit
chne_dtccr21	.btequ		4,dtccr21		; Chain transfer enable bit
rptint_dtccr21	.btequ		5,dtccr21		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 21
;-------------------------------------------------------
dtbls21			.equ		2CE9H
;
;-------------------------------------------------------
; DTC Transfer count register 21
;-------------------------------------------------------
dtcct21			.equ		2CEAH
;
;-------------------------------------------------------
; DTC Transfer count reload register 21
;-------------------------------------------------------
dtrld21			.equ		2CEBH
;
;-------------------------------------------------------
; DTC Source address register 21
;-------------------------------------------------------
dtsar21			.equ		2CECH
;
;-------------------------------------------------------
; DTC Destination register 21
;-------------------------------------------------------
dtdar21			.equ		2CEEH
;
;-------------------------------------------------------
; DTC Control register 22
;-------------------------------------------------------
dtccr22			.equ		2CF0H
;
mode_dtccr22	.btequ		0,dtccr22		; Transfer mode select bit
rptsel_dtccr22	.btequ		1,dtccr22		; Repeat area select bit
samod_dtccr22	.btequ		2,dtccr22		; Source address control bit
damod_dtccr22	.btequ		3,dtccr22		; Destination address control bit
chne_dtccr22	.btequ		4,dtccr22		; Chain transfer enable bit
rptint_dtccr22	.btequ		5,dtccr22		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 22
;-------------------------------------------------------
dtbls22			.equ		2CF1H
;
;-------------------------------------------------------
; DTC Transfer count register 22
;-------------------------------------------------------
dtcct22			.equ		2CF2H
;
;-------------------------------------------------------
; DTC Transfer count reload register 22
;-------------------------------------------------------
dtrld22			.equ		2CF3H
;
;-------------------------------------------------------
; DTC Source address register 22
;-------------------------------------------------------
dtsar22			.equ		2CF4H
;
;-------------------------------------------------------
; DTC Destination register 22
;-------------------------------------------------------
dtdar22			.equ		2CF6H
;
;-------------------------------------------------------
; DTC Control register 23
;-------------------------------------------------------
dtccr23			.equ		2CF8H
;
mode_dtccr23	.btequ		0,dtccr23		; Transfer mode select bit
rptsel_dtccr23	.btequ		1,dtccr23		; Repeat area select bit
samod_dtccr23	.btequ		2,dtccr23		; Source address control bit
damod_dtccr23	.btequ		3,dtccr23		; Destination address control bit
chne_dtccr23	.btequ		4,dtccr23		; Chain transfer enable bit
rptint_dtccr23	.btequ		5,dtccr23		; Repeat mode interrupt enable bit
;
;-------------------------------------------------------
; DTC Block size register 23
;-------------------------------------------------------
dtbls23			.equ		2CF9H
;
;-------------------------------------------------------
; DTC Transfer count register 23
;-------------------------------------------------------
dtcct23			.equ		2CFAH
;
;-------------------------------------------------------
; DTC Transfer count reload register 23
;-------------------------------------------------------
dtrld23			.equ		2CFBH
;
;-------------------------------------------------------
; DTC Source address register 23
;-------------------------------------------------------
dtsar23			.equ		2CFCH
;
;-------------------------------------------------------
; DTC Destination register 23
;-------------------------------------------------------
dtdar23			.equ		2CFEH
;
